@@ -56,6 +56,7 @@
 #include <sdf/Mesh.hh>
 #include <sdf/Pbr.hh>
 #include <sdf/Plane.hh>
+#include <sdf/Polyline.hh>
 #include <sdf/Sphere.hh>
 
 #include <string>
@@ -69,7 +70,7 @@ using namespace ignition;
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Entity_Type ignition::gazebo::convert(const std::string &_in)
+msgs::Entity_Type gazebo::convert(const std::string &_in)
 {
   msgs::Entity_Type out = msgs::Entity_Type_NONE;
 
@@ -107,7 +108,7 @@ msgs::Entity_Type ignition::gazebo::convert(const std::string &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-math::Pose3d ignition::gazebo::convert(const msgs::Pose &_in)
+math::Pose3d gazebo::convert(const msgs::Pose &_in)
 {
   math::Pose3d out(_in.position().x(),
                    _in.position().y(),
@@ -124,7 +125,7 @@ math::Pose3d ignition::gazebo::convert(const msgs::Pose &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Collision ignition::gazebo::convert(const sdf::Collision &_in)
+msgs::Collision gazebo::convert(const sdf::Collision &_in)
 {
   msgs::Collision out;
   out.set_name(_in.Name());
@@ -137,7 +138,7 @@ msgs::Collision ignition::gazebo::convert(const sdf::Collision &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Collision ignition::gazebo::convert(const msgs::Collision &_in)
+sdf::Collision gazebo::convert(const msgs::Collision &_in)
 {
   sdf::Collision out;
   out.SetName(_in.name());
@@ -149,7 +150,7 @@ sdf::Collision ignition::gazebo::convert(const msgs::Collision &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Geometry ignition::gazebo::convert(const sdf::Geometry &_in)
+msgs::Geometry gazebo::convert(const sdf::Geometry &_in)
 {
   msgs::Geometry out;
   if (_in.Type() == sdf::GeometryType::BOX && _in.BoxShape())
@@ -188,6 +189,20 @@ msgs::Geometry ignition::gazebo::convert(const sdf::Geometry &_in)
     meshMsg->set_submesh(meshSdf->Submesh());
     meshMsg->set_center_submesh(meshSdf->CenterSubmesh());
   }
+  else if (_in.Type() == sdf::GeometryType::POLYLINE &&
+      !_in.PolylineShape().empty())
+  {
+    out.set_type(msgs::Geometry::POLYLINE);
+    for (const auto &polyline : _in.PolylineShape())
+    {
+      auto polylineMsg = out.add_polyline();
+      polylineMsg->set_height(polyline.Height());
+      for (const auto &point : polyline.Points())
+      {
+        msgs::Set(polylineMsg->add_point(), point);
+      }
+    }
+  }
   else
   {
     ignerr << "Geometry type [" << static_cast<int>(_in.Type())
@@ -199,7 +214,7 @@ msgs::Geometry ignition::gazebo::convert(const sdf::Geometry &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Geometry ignition::gazebo::convert(const msgs::Geometry &_in)
+sdf::Geometry gazebo::convert(const msgs::Geometry &_in)
 {
   sdf::Geometry out;
   if (_in.type() == msgs::Geometry::BOX && _in.has_box())
@@ -252,6 +267,28 @@ sdf::Geometry ignition::gazebo::convert(const msgs::Geometry &_in)
 
     out.SetMeshShape(meshShape);
   }
+  else if (_in.type() == msgs::Geometry::POLYLINE && _in.polyline_size() > 0)
+  {
+    out.SetType(sdf::GeometryType::POLYLINE);
+
+    std::vector<sdf::Polyline> polylines;
+
+    for (auto i = 0; i < _in.polyline().size(); ++i)
+    {
+      auto polylineMsg = _in.polyline(i);
+      sdf::Polyline polylineShape;
+      polylineShape.SetHeight(polylineMsg.height());
+
+      for (auto j = 0; j < polylineMsg.point().size(); ++j)
+      {
+        polylineShape.AddPoint(msgs::Convert(polylineMsg.point(j)));
+      }
+
+      polylines.push_back(polylineShape);
+    }
+
+    out.SetPolylineShape(polylines);
+  }
   else
   {
     ignerr << "Geometry type [" << static_cast<int>(_in.type())
@@ -263,7 +300,7 @@ sdf::Geometry ignition::gazebo::convert(const msgs::Geometry &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Material ignition::gazebo::convert(const sdf::Material &_in)
+msgs::Material gazebo::convert(const sdf::Material &_in)
 {
   msgs::Material out;
   msgs::Set(out.mutable_ambient(), _in.Ambient());
@@ -317,7 +354,7 @@ msgs::Material ignition::gazebo::convert(const sdf::Material &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Material ignition::gazebo::convert(const msgs::Material &_in)
+sdf::Material gazebo::convert(const msgs::Material &_in)
 {
   sdf::Material out;
   out.SetAmbient(msgs::Convert(_in.ambient()));
@@ -356,7 +393,7 @@ sdf::Material ignition::gazebo::convert(const msgs::Material &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Actor ignition::gazebo::convert(const sdf::Actor &_in)
+msgs::Actor gazebo::convert(const sdf::Actor &_in)
 {
   msgs::Actor out;
   out.mutable_entity()->set_name(_in.Name());
@@ -396,7 +433,7 @@ msgs::Actor ignition::gazebo::convert(const sdf::Actor &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Actor ignition::gazebo::convert(const msgs::Actor &_in)
+sdf::Actor gazebo::convert(const msgs::Actor &_in)
 {
   sdf::Actor out;
   out.SetName(_in.entity().name());
@@ -439,7 +476,7 @@ sdf::Actor ignition::gazebo::convert(const msgs::Actor &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Light ignition::gazebo::convert(const sdf::Light &_in)
+msgs::Light gazebo::convert(const sdf::Light &_in)
 {
   msgs::Light out;
   out.set_name(_in.Name());
@@ -467,7 +504,7 @@ msgs::Light ignition::gazebo::convert(const sdf::Light &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Light ignition::gazebo::convert(const msgs::Light &_in)
+sdf::Light gazebo::convert(const msgs::Light &_in)
 {
   sdf::Light out;
   out.SetName(_in.name());
@@ -495,7 +532,7 @@ sdf::Light ignition::gazebo::convert(const msgs::Light &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::GUI ignition::gazebo::convert(const sdf::Gui &_in)
+msgs::GUI gazebo::convert(const sdf::Gui &_in)
 {
   msgs::GUI out;
 
@@ -534,12 +571,12 @@ msgs::GUI ignition::gazebo::convert(const sdf::Gui &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Time ignition::gazebo::convert(
+msgs::Time gazebo::convert(
     const std::chrono::steady_clock::duration &_in)
 {
   msgs::Time out;
 
-  auto secNsec = ignition::math::durationToSecNsec(_in);
+  auto secNsec = math::durationToSecNsec(_in);
 
   out.set_sec(secNsec.first);
   out.set_nsec(secNsec.second);
@@ -550,7 +587,7 @@ msgs::Time ignition::gazebo::convert(
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-std::chrono::steady_clock::duration ignition::gazebo::convert(
+std::chrono::steady_clock::duration gazebo::convert(
     const msgs::Time &_in)
 {
   return std::chrono::seconds(_in.sec()) + std::chrono::nanoseconds(_in.nsec());
@@ -559,7 +596,7 @@ std::chrono::steady_clock::duration ignition::gazebo::convert(
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Inertial ignition::gazebo::convert(const math::Inertiald &_in)
+msgs::Inertial gazebo::convert(const math::Inertiald &_in)
 {
   msgs::Inertial out;
   msgs::Set(out.mutable_pose(), _in.Pose());
@@ -576,7 +613,7 @@ msgs::Inertial ignition::gazebo::convert(const math::Inertiald &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-math::Inertiald ignition::gazebo::convert(const msgs::Inertial &_in)
+math::Inertiald gazebo::convert(const msgs::Inertial &_in)
 {
   math::MassMatrix3d massMatrix;
   massMatrix.SetMass(_in.mass());
@@ -596,7 +633,7 @@ math::Inertiald ignition::gazebo::convert(const msgs::Inertial &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Axis ignition::gazebo::convert(const sdf::JointAxis &_in)
+msgs::Axis gazebo::convert(const sdf::JointAxis &_in)
 {
   msgs::Axis out;
   msgs::Set(out.mutable_xyz(), _in.Xyz());
@@ -634,7 +671,7 @@ msgs::Axis ignition::gazebo::convert(const sdf::JointAxis &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::JointAxis ignition::gazebo::convert(const msgs::Axis &_in)
+sdf::JointAxis gazebo::convert(const msgs::Axis &_in)
 {
   sdf::JointAxis out;
   out.SetXyz(msgs::Convert(_in.xyz()));
@@ -659,7 +696,7 @@ sdf::JointAxis ignition::gazebo::convert(const msgs::Axis &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Scene ignition::gazebo::convert(const sdf::Scene &_in)
+msgs::Scene gazebo::convert(const sdf::Scene &_in)
 {
   msgs::Scene out;
   // todo(anyone) add Name to sdf::Scene?
@@ -675,7 +712,7 @@ msgs::Scene ignition::gazebo::convert(const sdf::Scene &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Scene ignition::gazebo::convert(const msgs::Scene &_in)
+sdf::Scene gazebo::convert(const msgs::Scene &_in)
 {
   sdf::Scene out;
   // todo(anyone) add SetName to sdf::Scene?
@@ -691,7 +728,7 @@ sdf::Scene ignition::gazebo::convert(const msgs::Scene &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Atmosphere ignition::gazebo::convert(const sdf::Atmosphere &_in)
+msgs::Atmosphere gazebo::convert(const sdf::Atmosphere &_in)
 {
   msgs::Atmosphere out;
   out.set_temperature(_in.Temperature().Kelvin());
@@ -709,7 +746,7 @@ msgs::Atmosphere ignition::gazebo::convert(const sdf::Atmosphere &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Atmosphere ignition::gazebo::convert(const msgs::Atmosphere &_in)
+sdf::Atmosphere gazebo::convert(const msgs::Atmosphere &_in)
 {
   sdf::Atmosphere out;
   out.SetTemperature(math::Temperature(_in.temperature()));
@@ -725,16 +762,16 @@ sdf::Atmosphere ignition::gazebo::convert(const msgs::Atmosphere &_in)
 }
 
 //////////////////////////////////////////////////
-void ignition::gazebo::set(msgs::Time *_msg,
+void gazebo::set(msgs::Time *_msg,
     const std::chrono::steady_clock::duration &_in)
 {
-  auto secNsec = ignition::math::durationToSecNsec(_in);
+  auto secNsec = math::durationToSecNsec(_in);
   _msg->set_sec(secNsec.first);
   _msg->set_nsec(secNsec.second);
 }
 
 //////////////////////////////////////////////////
-void ignition::gazebo::set(msgs::WorldStatistics *_msg,
+void gazebo::set(msgs::WorldStatistics *_msg,
     const gazebo::UpdateInfo &_in)
 {
   set(_msg->mutable_sim_time(), _in.simTime);
@@ -746,7 +783,7 @@ void ignition::gazebo::set(msgs::WorldStatistics *_msg,
 
 //////////////////////////////////////////////////
 template<>
-msgs::Physics ignition::gazebo::convert(const sdf::Physics &_in)
+msgs::Physics gazebo::convert(const sdf::Physics &_in)
 {
   msgs::Physics out;
   out.set_max_step_size(_in.MaxStepSize());
@@ -756,7 +793,7 @@ msgs::Physics ignition::gazebo::convert(const sdf::Physics &_in)
 
 //////////////////////////////////////////////////
 template<>
-sdf::Physics ignition::gazebo::convert(const msgs::Physics &_in)
+sdf::Physics gazebo::convert(const msgs::Physics &_in)
 {
   sdf::Physics out;
   out.SetRealTimeFactor(_in.real_time_factor());
@@ -765,7 +802,7 @@ sdf::Physics ignition::gazebo::convert(const msgs::Physics &_in)
 }
 
 //////////////////////////////////////////////////
-void ignition::gazebo::set(msgs::SensorNoise *_msg, const sdf::Noise &_sdf)
+void gazebo::set(msgs::SensorNoise *_msg, const sdf::Noise &_sdf)
 {
   switch (_sdf.Type())
   {
@@ -794,7 +831,7 @@ void ignition::gazebo::set(msgs::SensorNoise *_msg, const sdf::Noise &_sdf)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Noise ignition::gazebo::convert(const msgs::SensorNoise &_in)
+sdf::Noise gazebo::convert(const msgs::SensorNoise &_in)
 {
   sdf::Noise out;
 
@@ -827,7 +864,7 @@ sdf::Noise ignition::gazebo::convert(const msgs::SensorNoise &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Sensor ignition::gazebo::convert(const sdf::Sensor &_in)
+msgs::Sensor gazebo::convert(const sdf::Sensor &_in)
 {
   msgs::Sensor out;
   out.set_name(_in.Name());
@@ -843,17 +880,17 @@ msgs::Sensor ignition::gazebo::convert(const sdf::Sensor &_in)
       msgs::MagnetometerSensor *sensor = out.mutable_magnetometer();
       if (_in.MagnetometerSensor()->XNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(sensor->mutable_x_noise(),
+        gazebo::set(sensor->mutable_x_noise(),
             _in.MagnetometerSensor()->XNoise());
       }
       if (_in.MagnetometerSensor()->YNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(sensor->mutable_y_noise(),
+        gazebo::set(sensor->mutable_y_noise(),
             _in.MagnetometerSensor()->YNoise());
       }
       if (_in.MagnetometerSensor()->ZNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(sensor->mutable_z_noise(),
+        gazebo::set(sensor->mutable_z_noise(),
             _in.MagnetometerSensor()->ZNoise());
       }
     }
@@ -903,13 +940,13 @@ msgs::Sensor ignition::gazebo::convert(const sdf::Sensor &_in)
       if (_in.AltimeterSensor()->VerticalPositionNoise().Type()
           != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(sensor->mutable_vertical_position_noise(),
+        gazebo::set(sensor->mutable_vertical_position_noise(),
             _in.AltimeterSensor()->VerticalPositionNoise());
       }
       if (_in.AltimeterSensor()->VerticalVelocityNoise().Type()
           != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(sensor->mutable_vertical_velocity_noise(),
+        gazebo::set(sensor->mutable_vertical_velocity_noise(),
             _in.AltimeterSensor()->VerticalVelocityNoise());
       }
     }
@@ -928,7 +965,7 @@ msgs::Sensor ignition::gazebo::convert(const sdf::Sensor &_in)
       if (_in.AirPressureSensor()->PressureNoise().Type()
           != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(sensor->mutable_pressure_noise(),
+        gazebo::set(sensor->mutable_pressure_noise(),
             _in.AirPressureSensor()->PressureNoise());
       }
       sensor->set_reference_altitude(
@@ -949,38 +986,38 @@ msgs::Sensor ignition::gazebo::convert(const sdf::Sensor &_in)
 
       if (sdfImu->LinearAccelerationXNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(
+        gazebo::set(
             sensor->mutable_linear_acceleration()->mutable_x_noise(),
             sdfImu->LinearAccelerationXNoise());
       }
       if (sdfImu->LinearAccelerationYNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(
+        gazebo::set(
             sensor->mutable_linear_acceleration()->mutable_y_noise(),
             sdfImu->LinearAccelerationYNoise());
       }
       if (sdfImu->LinearAccelerationZNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(
+        gazebo::set(
             sensor->mutable_linear_acceleration()->mutable_z_noise(),
             sdfImu->LinearAccelerationZNoise());
       }
 
       if (sdfImu->AngularVelocityXNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(
+        gazebo::set(
             sensor->mutable_angular_velocity()->mutable_x_noise(),
             sdfImu->AngularVelocityXNoise());
       }
       if (sdfImu->AngularVelocityYNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(
+        gazebo::set(
             sensor->mutable_angular_velocity()->mutable_y_noise(),
             sdfImu->AngularVelocityYNoise());
       }
       if (sdfImu->AngularVelocityZNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(
+        gazebo::set(
             sensor->mutable_angular_velocity()->mutable_z_noise(),
             sdfImu->AngularVelocityZNoise());
       }
@@ -1014,7 +1051,7 @@ msgs::Sensor ignition::gazebo::convert(const sdf::Sensor &_in)
 
       if (sdfLidar->LidarNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(sensor->mutable_noise(), sdfLidar->LidarNoise());
+        gazebo::set(sensor->mutable_noise(), sdfLidar->LidarNoise());
       }
       sensor->set_horizontal_samples(sdfLidar->HorizontalScanSamples());
       sensor->set_horizontal_resolution(sdfLidar->HorizontalScanResolution());
@@ -1044,7 +1081,7 @@ msgs::Sensor ignition::gazebo::convert(const sdf::Sensor &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Sensor ignition::gazebo::convert(const msgs::Sensor &_in)
+sdf::Sensor gazebo::convert(const msgs::Sensor &_in)
 {
   sdf::Sensor out;
   out.SetName(_in.name());
@@ -1061,17 +1098,17 @@ sdf::Sensor ignition::gazebo::convert(const msgs::Sensor &_in)
     {
       if (_in.magnetometer().has_x_noise())
       {
-        sensor.SetXNoise(ignition::gazebo::convert<sdf::Noise>(
+        sensor.SetXNoise(gazebo::convert<sdf::Noise>(
               _in.magnetometer().x_noise()));
       }
       if (_in.magnetometer().has_y_noise())
       {
-        sensor.SetYNoise(ignition::gazebo::convert<sdf::Noise>(
+        sensor.SetYNoise(gazebo::convert<sdf::Noise>(
               _in.magnetometer().y_noise()));
       }
       if (_in.magnetometer().has_z_noise())
       {
-        sensor.SetZNoise(ignition::gazebo::convert<sdf::Noise>(
+        sensor.SetZNoise(gazebo::convert<sdf::Noise>(
               _in.magnetometer().z_noise()));
       }
     }
@@ -1126,13 +1163,13 @@ sdf::Sensor ignition::gazebo::convert(const msgs::Sensor &_in)
     {
       if (_in.altimeter().has_vertical_position_noise())
       {
-        sensor.SetVerticalPositionNoise(ignition::gazebo::convert<sdf::Noise>(
+        sensor.SetVerticalPositionNoise(gazebo::convert<sdf::Noise>(
               _in.altimeter().vertical_position_noise()));
       }
 
       if (_in.altimeter().has_vertical_velocity_noise())
       {
-        sensor.SetVerticalVelocityNoise(ignition::gazebo::convert<sdf::Noise>(
+        sensor.SetVerticalVelocityNoise(gazebo::convert<sdf::Noise>(
               _in.altimeter().vertical_velocity_noise()));
       }
     }
@@ -1151,7 +1188,7 @@ sdf::Sensor ignition::gazebo::convert(const msgs::Sensor &_in)
     {
       if (_in.air_pressure().has_pressure_noise())
       {
-        sensor.SetPressureNoise(ignition::gazebo::convert<sdf::Noise>(
+        sensor.SetPressureNoise(gazebo::convert<sdf::Noise>(
               _in.air_pressure().pressure_noise()));
       }
 
@@ -1175,19 +1212,19 @@ sdf::Sensor ignition::gazebo::convert(const msgs::Sensor &_in)
         if (_in.imu().linear_acceleration().has_x_noise())
         {
           sensor.SetLinearAccelerationXNoise(
-              ignition::gazebo::convert<sdf::Noise>(
+              gazebo::convert<sdf::Noise>(
                 _in.imu().linear_acceleration().x_noise()));
         }
         if (_in.imu().linear_acceleration().has_y_noise())
         {
           sensor.SetLinearAccelerationYNoise(
-              ignition::gazebo::convert<sdf::Noise>(
+              gazebo::convert<sdf::Noise>(
                 _in.imu().linear_acceleration().y_noise()));
         }
         if (_in.imu().linear_acceleration().has_z_noise())
         {
           sensor.SetLinearAccelerationZNoise(
-              ignition::gazebo::convert<sdf::Noise>(
+              gazebo::convert<sdf::Noise>(
                 _in.imu().linear_acceleration().z_noise()));
         }
       }
@@ -1197,19 +1234,19 @@ sdf::Sensor ignition::gazebo::convert(const msgs::Sensor &_in)
         if (_in.imu().angular_velocity().has_x_noise())
         {
           sensor.SetAngularVelocityXNoise(
-              ignition::gazebo::convert<sdf::Noise>(
+              gazebo::convert<sdf::Noise>(
                 _in.imu().angular_velocity().x_noise()));
         }
         if (_in.imu().angular_velocity().has_y_noise())
         {
           sensor.SetAngularVelocityYNoise(
-              ignition::gazebo::convert<sdf::Noise>(
+              gazebo::convert<sdf::Noise>(
                 _in.imu().angular_velocity().y_noise()));
         }
         if (_in.imu().angular_velocity().has_z_noise())
         {
           sensor.SetAngularVelocityZNoise(
-              ignition::gazebo::convert<sdf::Noise>(
+              gazebo::convert<sdf::Noise>(
                 _in.imu().angular_velocity().z_noise()));
         }
       }
@@ -1266,7 +1303,7 @@ sdf::Sensor ignition::gazebo::convert(const msgs::Sensor &_in)
 
       if (_in.lidar().has_noise())
       {
-        sensor.SetLidarNoise(ignition::gazebo::convert<sdf::Noise>(
+        sensor.SetLidarNoise(gazebo::convert<sdf::Noise>(
               _in.lidar().noise()));
       }
     }
@@ -1284,7 +1321,7 @@ sdf::Sensor ignition::gazebo::convert(const msgs::Sensor &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::WorldStatistics ignition::gazebo::convert(const gazebo::UpdateInfo &_in)
+msgs::WorldStatistics gazebo::convert(const gazebo::UpdateInfo &_in)
 {
   msgs::WorldStatistics out;
   set(&out, _in);
@@ -1294,7 +1331,7 @@ msgs::WorldStatistics ignition::gazebo::convert(const gazebo::UpdateInfo &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-gazebo::UpdateInfo ignition::gazebo::convert(const msgs::WorldStatistics &_in)
+gazebo::UpdateInfo gazebo::convert(const msgs::WorldStatistics &_in)
 {
   gazebo::UpdateInfo out;
   out.iterations = _in.iterations();
@@ -1308,7 +1345,7 @@ gazebo::UpdateInfo ignition::gazebo::convert(const msgs::WorldStatistics &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::AxisAlignedBox ignition::gazebo::convert(const math::AxisAlignedBox &_in)
+msgs::AxisAlignedBox gazebo::convert(const math::AxisAlignedBox &_in)
 {
   msgs::AxisAlignedBox out;
   msgs::Set(out.mutable_min_corner(), _in.Min());
@@ -1319,7 +1356,7 @@ msgs::AxisAlignedBox ignition::gazebo::convert(const math::AxisAlignedBox &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-math::AxisAlignedBox ignition::gazebo::convert(const msgs::AxisAlignedBox &_in)
+math::AxisAlignedBox gazebo::convert(const msgs::AxisAlignedBox &_in)
 {
   math::AxisAlignedBox out;
   out.Min() = msgs::Convert(_in.min_corner());
