@@ -56,7 +56,7 @@ using namespace ignition;
 using namespace gazebo;
 
 /////////////////////////////////////////////////
-class EntityCompMgrTest : public gazebo::EntityComponentManager
+class EntityCompMgrTest : public EntityComponentManager
 {
   public: void ProcessEntityRemovals()
   {
@@ -124,7 +124,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
 
       EXPECT_EQ("default", _name->Data());
       EXPECT_DOUBLE_EQ(0.001, _physics->Data().MaxStepSize());
-      EXPECT_DOUBLE_EQ(1.0, _physics->Data().RealTimeFactor());
+      EXPECT_DOUBLE_EQ(0.0, _physics->Data().RealTimeFactor());
 
       worldCount++;
 
@@ -162,21 +162,21 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
 
       if (modelCount == 1)
       {
-        EXPECT_EQ(ignition::math::Pose3d(1, 2, 3, 0, 0, 1),
+        EXPECT_EQ(math::Pose3d(1, 2, 3, 0, 0, 1),
             _pose->Data());
         EXPECT_EQ("box", _name->Data());
         boxModelEntity = _entity;
       }
       else if (modelCount == 2)
       {
-        EXPECT_EQ(ignition::math::Pose3d(-1, -2, -3, 0, 0, 1),
+        EXPECT_EQ(math::Pose3d(-1, -2, -3, 0, 0, 1),
             _pose->Data());
         EXPECT_EQ("cylinder", _name->Data());
         cylModelEntity = _entity;
       }
       else if (modelCount == 3)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0, 0, 0, 0, 0, 1),
+        EXPECT_EQ(math::Pose3d(0, 0, 0, 0, 0, 1),
             _pose->Data());
         EXPECT_EQ("sphere", _name->Data());
         sphModelEntity = _entity;
@@ -213,7 +213,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
 
       if (linkCount == 1)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.1, 0.1, 0.1, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.1, 0.1, 0.1, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("box_link", _name->Data());
 
@@ -224,7 +224,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
       }
       else if (linkCount == 2)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.2, 0.2, 0.2, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.2, 0.2, 0.2, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("cylinder_link", _name->Data());
 
@@ -235,7 +235,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
       }
       else if (linkCount == 3)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.3, 0.3, 0.3, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.3, 0.3, 0.3, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("sphere_link", _name->Data());
 
@@ -311,7 +311,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
 
       if (collisionCount == 1)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.11, 0.11, 0.11, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.11, 0.11, 0.11, 0, 0, 0),
             _pose->Data());
 
         EXPECT_EQ("box_collision", _name->Data());
@@ -326,7 +326,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
       }
       else if (collisionCount == 2)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.21, 0.21, 0.21, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.21, 0.21, 0.21, 0, 0, 0),
             _pose->Data());
 
         EXPECT_EQ("cylinder_collision", _name->Data());
@@ -341,7 +341,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
       }
       else if (collisionCount == 3)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.31, 0.31, 0.31, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.31, 0.31, 0.31, 0, 0, 0),
             _pose->Data());
 
         EXPECT_EQ("sphere_collision", _name->Data());
@@ -393,7 +393,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
 
       if (visualCount == 1)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.12, 0.12, 0.12, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.12, 0.12, 0.12, 0, 0, 0),
             _pose->Data());
 
         EXPECT_EQ("box_visual", _name->Data());
@@ -417,7 +417,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
       }
       else if (visualCount == 2)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.22, 0.22, 0.22, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.22, 0.22, 0.22, 0, 0, 0),
             _pose->Data());
 
         EXPECT_EQ("cylinder_visual", _name->Data());
@@ -441,7 +441,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
       }
       else if (visualCount == 3)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.32, 0.32, 0.32, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.32, 0.32, 0.32, 0, 0, 0),
             _pose->Data());
 
         EXPECT_EQ("sphere_visual", _name->Data());
@@ -486,7 +486,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
 
       lightCount++;
 
-      EXPECT_EQ(ignition::math::Pose3d(0.0, 0.0, 10, 0, 0, 0),
+      EXPECT_EQ(math::Pose3d(0.0, 0.0, 10, 0, 0, 0),
           _pose->Data());
 
       EXPECT_EQ("sun", _name->Data());
@@ -496,19 +496,19 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
 
       EXPECT_EQ("sun", _light->Data().Name());
       EXPECT_EQ(sdf::LightType::DIRECTIONAL, _light->Data().Type());
-      EXPECT_EQ(ignition::math::Pose3d(0, 0, 10, 0, 0, 0),
+      EXPECT_EQ(math::Pose3d(0, 0, 10, 0, 0, 0),
           _light->Data().RawPose());
       EXPECT_EQ("", _light->Data().PoseRelativeTo());
       EXPECT_TRUE(_light->Data().CastShadows());
-      EXPECT_EQ(ignition::math::Color(0.8f, 0.8f, 0.8f, 1),
+      EXPECT_EQ(math::Color(0.8f, 0.8f, 0.8f, 1),
           _light->Data().Diffuse());
-      EXPECT_EQ(ignition::math::Color(0.2f, 0.2f, 0.2f, 1),
+      EXPECT_EQ(math::Color(0.2f, 0.2f, 0.2f, 1),
           _light->Data().Specular());
       EXPECT_DOUBLE_EQ(1000, _light->Data().AttenuationRange());
       EXPECT_DOUBLE_EQ(0.9, _light->Data().ConstantAttenuationFactor());
       EXPECT_DOUBLE_EQ(0.01, _light->Data().LinearAttenuationFactor());
       EXPECT_DOUBLE_EQ(0.001, _light->Data().QuadraticAttenuationFactor());
-      EXPECT_EQ(ignition::math::Vector3d(-0.5, 0.1, -0.9),
+      EXPECT_EQ(math::Vector3d(-0.5, 0.1, -0.9),
           _light->Data().Direction());
       return true;
     });
@@ -583,7 +583,7 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
       EXPECT_EQ(worldEntity, _parent->Data());
       EXPECT_EQ(worldEntity, this->ecm.ParentEntity(_entity));
 
-      EXPECT_EQ(ignition::math::Pose3d(0, 0, 0, 0, 0, 0),
+      EXPECT_EQ(math::Pose3d(0, 0, 0, 0, 0, 0),
           _pose->Data());
       EXPECT_EQ("sphere", _name->Data());
       sphModelEntity = _entity;
@@ -614,7 +614,7 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
 
       linkCount++;
 
-      EXPECT_EQ(ignition::math::Pose3d(0.0, 0.0, 0.0, 0, 0, 0),
+      EXPECT_EQ(math::Pose3d(0.0, 0.0, 0.0, 0, 0, 0),
           _pose->Data());
       EXPECT_EQ("sphere_link", _name->Data());
       EXPECT_EQ(sphModelEntity, _parent->Data());
@@ -653,7 +653,7 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
 
       visualCount++;
 
-      EXPECT_EQ(ignition::math::Pose3d(0.0, 0.0, 0.0, 0, 0, 0),
+      EXPECT_EQ(math::Pose3d(0.0, 0.0, 0.0, 0, 0, 0),
           _pose->Data());
 
       EXPECT_EQ("sphere_visual", _name->Data());
@@ -695,7 +695,7 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
       // light attached to link
       if (lightCount == 1u)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.0, 0.0, 1.0, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.0, 0.0, 1.0, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("link_light_point", _name->Data());
 
@@ -704,13 +704,13 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
 
         EXPECT_EQ("link_light_point", _light->Data().Name());
         EXPECT_EQ(sdf::LightType::POINT, _light->Data().Type());
-        EXPECT_EQ(ignition::math::Pose3d(0, 0, 1, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0, 0, 1, 0, 0, 0),
             _light->Data().RawPose());
         EXPECT_EQ(std::string(), _light->Data().PoseRelativeTo());
         EXPECT_FALSE(_light->Data().CastShadows());
-        EXPECT_EQ(ignition::math::Color(0.0f, 0.0f, 1.0f, 1),
+        EXPECT_EQ(math::Color(0.0f, 0.0f, 1.0f, 1),
             _light->Data().Diffuse());
-        EXPECT_EQ(ignition::math::Color(0.1f, 0.1f, 0.1f, 1),
+        EXPECT_EQ(math::Color(0.1f, 0.1f, 0.1f, 1),
             _light->Data().Specular());
         EXPECT_DOUBLE_EQ(2, _light->Data().AttenuationRange());
         EXPECT_DOUBLE_EQ(0.05, _light->Data().ConstantAttenuationFactor());
@@ -720,7 +720,7 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
       // directional light in the world
       else if (lightCount == 2u)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.0, 0.0, 10, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.0, 0.0, 10, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("directional", _name->Data());
 
@@ -729,25 +729,25 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
 
         EXPECT_EQ("directional", _light->Data().Name());
         EXPECT_EQ(sdf::LightType::DIRECTIONAL, _light->Data().Type());
-        EXPECT_EQ(ignition::math::Pose3d(0, 0, 10, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0, 0, 10, 0, 0, 0),
             _light->Data().RawPose());
         EXPECT_EQ(std::string(), _light->Data().PoseRelativeTo());
         EXPECT_TRUE(_light->Data().CastShadows());
-        EXPECT_EQ(ignition::math::Color(0.8f, 0.8f, 0.8f, 1),
+        EXPECT_EQ(math::Color(0.8f, 0.8f, 0.8f, 1),
             _light->Data().Diffuse());
-        EXPECT_EQ(ignition::math::Color(0.2f, 0.2f, 0.2f, 1),
+        EXPECT_EQ(math::Color(0.2f, 0.2f, 0.2f, 1),
             _light->Data().Specular());
         EXPECT_DOUBLE_EQ(100, _light->Data().AttenuationRange());
         EXPECT_DOUBLE_EQ(0.9, _light->Data().ConstantAttenuationFactor());
         EXPECT_DOUBLE_EQ(0.01, _light->Data().LinearAttenuationFactor());
         EXPECT_DOUBLE_EQ(0.001, _light->Data().QuadraticAttenuationFactor());
-        EXPECT_EQ(ignition::math::Vector3d(0.5, 0.2, -0.9),
+        EXPECT_EQ(math::Vector3d(0.5, 0.2, -0.9),
             _light->Data().Direction());
       }
       // point light in the world
       else if (lightCount == 3u)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.0, -1.5, 3, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.0, -1.5, 3, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("point", _name->Data());
 
@@ -756,13 +756,13 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
 
         EXPECT_EQ("point", _light->Data().Name());
         EXPECT_EQ(sdf::LightType::POINT, _light->Data().Type());
-        EXPECT_EQ(ignition::math::Pose3d(0, -1.5, 3, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0, -1.5, 3, 0, 0, 0),
             _light->Data().RawPose());
         EXPECT_EQ(std::string(), _light->Data().PoseRelativeTo());
         EXPECT_FALSE(_light->Data().CastShadows());
-        EXPECT_EQ(ignition::math::Color(1.0f, 0.0f, 0.0f, 1),
+        EXPECT_EQ(math::Color(1.0f, 0.0f, 0.0f, 1),
             _light->Data().Diffuse());
-        EXPECT_EQ(ignition::math::Color(0.1f, 0.1f, 0.1f, 1),
+        EXPECT_EQ(math::Color(0.1f, 0.1f, 0.1f, 1),
             _light->Data().Specular());
         EXPECT_DOUBLE_EQ(4, _light->Data().AttenuationRange());
         EXPECT_DOUBLE_EQ(0.2, _light->Data().ConstantAttenuationFactor());
@@ -772,7 +772,7 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
       // spot light in the world
       else if (lightCount == 4u)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.0, 1.5, 3, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.0, 1.5, 3, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("spot", _name->Data());
 
@@ -781,19 +781,19 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
 
         EXPECT_EQ("spot", _light->Data().Name());
         EXPECT_EQ(sdf::LightType::SPOT, _light->Data().Type());
-        EXPECT_EQ(ignition::math::Pose3d(0, 1.5, 3, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0, 1.5, 3, 0, 0, 0),
             _light->Data().RawPose());
         EXPECT_EQ(std::string(), _light->Data().PoseRelativeTo());
         EXPECT_FALSE(_light->Data().CastShadows());
-        EXPECT_EQ(ignition::math::Color(0.0f, 1.0f, 0.0f, 1),
+        EXPECT_EQ(math::Color(0.0f, 1.0f, 0.0f, 1),
             _light->Data().Diffuse());
-        EXPECT_EQ(ignition::math::Color(0.2f, 0.2f, 0.2f, 1),
+        EXPECT_EQ(math::Color(0.2f, 0.2f, 0.2f, 1),
             _light->Data().Specular());
         EXPECT_DOUBLE_EQ(5, _light->Data().AttenuationRange());
         EXPECT_DOUBLE_EQ(0.3, _light->Data().ConstantAttenuationFactor());
         EXPECT_DOUBLE_EQ(0.4, _light->Data().LinearAttenuationFactor());
         EXPECT_DOUBLE_EQ(0.001, _light->Data().QuadraticAttenuationFactor());
-        EXPECT_EQ(ignition::math::Vector3d(0.0, 0.0, -1.0),
+        EXPECT_EQ(math::Vector3d(0.0, 0.0, -1.0),
             _light->Data().Direction());
         EXPECT_DOUBLE_EQ(0.1, _light->Data().SpotInnerAngle().Radian());
         EXPECT_DOUBLE_EQ(0.5, _light->Data().SpotOuterAngle().Radian());
@@ -1068,7 +1068,7 @@ size_t removedCount(EntityCompMgrTest &_manager)
 {
   size_t count = 0;
   _manager.EachRemoved<Ts...>(
-      [&](const ignition::gazebo::Entity &, const Ts *...) -> bool
+      [&](const Entity &, const Ts *...) -> bool
       {
         ++count;
         return true;
