@@ -68,11 +68,11 @@ namespace gazebo
 inline namespace IGNITION_GAZEBO_VERSION_NAMESPACE {
 namespace components
 {
-using IntComponent = components::Component<int, class IntComponentTag>;
+using IntComponent = Component<int, class IntComponentTag>;
 IGN_GAZEBO_REGISTER_COMPONENT("ign_gazebo_components.IntComponent",
     IntComponent)
 
-using DoubleComponent = components::Component<double, class DoubleComponentTag>;
+using DoubleComponent = Component<double, class DoubleComponentTag>;
 IGN_GAZEBO_REGISTER_COMPONENT("ign_gazebo_components.DoubleComponent",
     DoubleComponent)
 }
@@ -118,31 +118,31 @@ TEST_P(SimulationRunnerTest, CreateEntities)
 
   // Check component types
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::World::typeId));
+      World::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::Model::typeId));
+      Model::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::CanonicalLink::typeId));
+      CanonicalLink::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::Link::typeId));
+      Link::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::Collision::typeId));
+      Collision::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::Visual::typeId));
+      Visual::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::Light::typeId));
+      Light::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::Name::typeId));
+      Name::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::ParentEntity::typeId));
+      ParentEntity::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::Geometry::typeId));
+      Geometry::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
       components::Material::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::Inertial::typeId));
+      Inertial::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::Wind::typeId));
+      Wind::typeId));
 
   // Check entities
   // 1 x world + 1 x (default) level + 1 x wind + 3 x model + 3 x link + 3 x
@@ -152,10 +152,10 @@ TEST_P(SimulationRunnerTest, CreateEntities)
   // Check worlds
   unsigned int worldCount{0};
   Entity worldEntity = kNullEntity;
-  runner.EntityCompMgr().Each<components::World,
+  runner.EntityCompMgr().Each<World,
                             components::Name>(
     [&](const Entity &_entity,
-        const components::World *_world,
+        const World *_world,
         const components::Name *_name)->bool
     {
       EXPECT_NE(nullptr, _world);
@@ -181,14 +181,14 @@ TEST_P(SimulationRunnerTest, CreateEntities)
   Entity boxModelEntity = kNullEntity;
   Entity cylModelEntity = kNullEntity;
   Entity sphModelEntity = kNullEntity;
-  runner.EntityCompMgr().Each<components::Model,
-                            components::Pose,
-                            components::ParentEntity,
+  runner.EntityCompMgr().Each<Model,
+                            Pose,
+                            ParentEntity,
                             components::Name>(
     [&](const Entity &_entity,
-        const components::Model *_model,
-        const components::Pose *_pose,
-        const components::ParentEntity *_parent,
+        const Model *_model,
+        const Pose *_pose,
+        const ParentEntity *_parent,
         const components::Name *_name)->bool
     {
       EXPECT_NE(nullptr, _model);
@@ -201,21 +201,21 @@ TEST_P(SimulationRunnerTest, CreateEntities)
       EXPECT_EQ(worldEntity, _parent->Data());
       if (modelCount == 1)
       {
-        EXPECT_EQ(ignition::math::Pose3d(1, 2, 3, 0, 0, 1),
+        EXPECT_EQ(math::Pose3d(1, 2, 3, 0, 0, 1),
             _pose->Data());
         EXPECT_EQ("box", _name->Data());
         boxModelEntity = _entity;
       }
       else if (modelCount == 2)
       {
-        EXPECT_EQ(ignition::math::Pose3d(-1, -2, -3, 0, 0, 1),
+        EXPECT_EQ(math::Pose3d(-1, -2, -3, 0, 0, 1),
             _pose->Data());
         EXPECT_EQ("cylinder", _name->Data());
         cylModelEntity = _entity;
       }
       else if (modelCount == 3)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0, 0, 0, 0, 0, 1),
+        EXPECT_EQ(math::Pose3d(0, 0, 0, 0, 0, 1),
             _pose->Data());
         EXPECT_EQ("sphere", _name->Data());
         sphModelEntity = _entity;
@@ -233,14 +233,14 @@ TEST_P(SimulationRunnerTest, CreateEntities)
   Entity boxLinkEntity = kNullEntity;
   Entity cylLinkEntity = kNullEntity;
   Entity sphLinkEntity = kNullEntity;
-  runner.EntityCompMgr().Each<components::Link,
-                            components::Pose,
-                            components::ParentEntity,
+  runner.EntityCompMgr().Each<Link,
+                            Pose,
+                            ParentEntity,
                             components::Name>(
     [&](const Entity &_entity,
-        const components::Link *_link,
-        const components::Pose *_pose,
-        const components::ParentEntity *_parent,
+        const Link *_link,
+        const Pose *_pose,
+        const ParentEntity *_parent,
         const components::Name *_name)->bool
     {
       EXPECT_NE(nullptr, _link);
@@ -252,7 +252,7 @@ TEST_P(SimulationRunnerTest, CreateEntities)
 
       if (linkCount == 1)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.1, 0.1, 0.1, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.1, 0.1, 0.1, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("box_link", _name->Data());
         EXPECT_EQ(boxModelEntity, _parent->Data());
@@ -260,7 +260,7 @@ TEST_P(SimulationRunnerTest, CreateEntities)
       }
       else if (linkCount == 2)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.2, 0.2, 0.2, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.2, 0.2, 0.2, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("cylinder_link", _name->Data());
         EXPECT_EQ(cylModelEntity, _parent->Data());
@@ -268,7 +268,7 @@ TEST_P(SimulationRunnerTest, CreateEntities)
       }
       else if (linkCount == 3)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.3, 0.3, 0.3, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.3, 0.3, 0.3, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("sphere_link", _name->Data());
         EXPECT_EQ(sphModelEntity, _parent->Data());
@@ -284,10 +284,10 @@ TEST_P(SimulationRunnerTest, CreateEntities)
 
   // Check inertials
   unsigned int inertialCount{0};
-  runner.EntityCompMgr().Each<components::Link, components::Inertial>(
+  runner.EntityCompMgr().Each<Link, Inertial>(
     [&](const Entity & _entity,
-        const components::Link *_link,
-        const components::Inertial *_inertial)->bool
+        const Link *_link,
+        const Inertial *_inertial)->bool
     {
       EXPECT_NE(nullptr, _link);
       EXPECT_NE(nullptr, _inertial);
@@ -319,16 +319,16 @@ TEST_P(SimulationRunnerTest, CreateEntities)
 
   // Check collisions
   unsigned int collisionCount{0};
-  runner.EntityCompMgr().Each<components::Collision,
-                            components::Geometry,
-                            components::Pose,
-                            components::ParentEntity,
+  runner.EntityCompMgr().Each<Collision,
+                            Geometry,
+                            Pose,
+                            ParentEntity,
                             components::Name>(
     [&](const Entity &/*_entity*/,
-        const components::Collision *_collision,
-        const components::Geometry *_geometry,
-        const components::Pose *_pose,
-        const components::ParentEntity *_parent,
+        const Collision *_collision,
+        const Geometry *_geometry,
+        const Pose *_pose,
+        const ParentEntity *_parent,
         const components::Name *_name)->bool
     {
       EXPECT_NE(nullptr, _collision);
@@ -341,7 +341,7 @@ TEST_P(SimulationRunnerTest, CreateEntities)
 
       if (collisionCount == 1)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.11, 0.11, 0.11, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.11, 0.11, 0.11, 0, 0, 0),
             _pose->Data());
 
         EXPECT_EQ("box_collision", _name->Data());
@@ -355,7 +355,7 @@ TEST_P(SimulationRunnerTest, CreateEntities)
       }
       else if (collisionCount == 2)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.21, 0.21, 0.21, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.21, 0.21, 0.21, 0, 0, 0),
             _pose->Data());
 
         EXPECT_EQ("cylinder_collision", _name->Data());
@@ -369,7 +369,7 @@ TEST_P(SimulationRunnerTest, CreateEntities)
       }
       else if (collisionCount == 3)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.31, 0.31, 0.31, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.31, 0.31, 0.31, 0, 0, 0),
             _pose->Data());
 
         EXPECT_EQ("sphere_collision", _name->Data());
@@ -387,18 +387,18 @@ TEST_P(SimulationRunnerTest, CreateEntities)
 
   // Check visuals
   unsigned int visualCount{0};
-  runner.EntityCompMgr().Each<components::Visual,
-                            components::Geometry,
+  runner.EntityCompMgr().Each<Visual,
+                            Geometry,
                             components::Material,
-                            components::Pose,
-                            components::ParentEntity,
+                            Pose,
+                            ParentEntity,
                             components::Name>(
     [&](const Entity &/*_entity*/,
-        const components::Visual *_visual,
-        const components::Geometry *_geometry,
+        const Visual *_visual,
+        const Geometry *_geometry,
         const components::Material *_material,
-        const components::Pose *_pose,
-        const components::ParentEntity *_parent,
+        const Pose *_pose,
+        const ParentEntity *_parent,
         const components::Name *_name)->bool
     {
       EXPECT_NE(nullptr, _visual);
@@ -412,7 +412,7 @@ TEST_P(SimulationRunnerTest, CreateEntities)
 
       if (visualCount == 1)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.12, 0.12, 0.12, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.12, 0.12, 0.12, 0, 0, 0),
             _pose->Data());
 
         EXPECT_EQ("box_visual", _name->Data());
@@ -431,7 +431,7 @@ TEST_P(SimulationRunnerTest, CreateEntities)
       }
       else if (visualCount == 2)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.22, 0.22, 0.22, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.22, 0.22, 0.22, 0, 0, 0),
             _pose->Data());
 
         EXPECT_EQ("cylinder_visual", _name->Data());
@@ -450,7 +450,7 @@ TEST_P(SimulationRunnerTest, CreateEntities)
       }
       else if (visualCount == 3)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.32, 0.32, 0.32, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.32, 0.32, 0.32, 0, 0, 0),
             _pose->Data());
 
         EXPECT_EQ("sphere_visual", _name->Data());
@@ -473,14 +473,14 @@ TEST_P(SimulationRunnerTest, CreateEntities)
 
   // Check lights
   unsigned int lightCount{0};
-  runner.EntityCompMgr().Each<components::Light,
-                            components::Pose,
-                            components::ParentEntity,
+  runner.EntityCompMgr().Each<Light,
+                            Pose,
+                            ParentEntity,
                             components::Name>(
     [&](const Entity &/*_entity*/,
-        const components::Light *_light,
-        const components::Pose *_pose,
-        const components::ParentEntity *_parent,
+        const Light *_light,
+        const Pose *_pose,
+        const ParentEntity *_parent,
         const components::Name *_name)->bool
     {
       EXPECT_NE(nullptr, _light);
@@ -490,7 +490,7 @@ TEST_P(SimulationRunnerTest, CreateEntities)
 
       lightCount++;
 
-      EXPECT_EQ(ignition::math::Pose3d(0.0, 0.0, 10, 0, 0, 0),
+      EXPECT_EQ(math::Pose3d(0.0, 0.0, 10, 0, 0, 0),
           _pose->Data());
 
       EXPECT_EQ("sun", _name->Data());
@@ -499,19 +499,19 @@ TEST_P(SimulationRunnerTest, CreateEntities)
 
       EXPECT_EQ("sun", _light->Data().Name());
       EXPECT_EQ(sdf::LightType::DIRECTIONAL, _light->Data().Type());
-      EXPECT_EQ(ignition::math::Pose3d(0, 0, 10, 0, 0, 0),
+      EXPECT_EQ(math::Pose3d(0, 0, 10, 0, 0, 0),
           _light->Data().RawPose());
       EXPECT_EQ("", _light->Data().PoseRelativeTo());
       EXPECT_TRUE(_light->Data().CastShadows());
-      EXPECT_EQ(ignition::math::Color(0.8f, 0.8f, 0.8f, 1),
+      EXPECT_EQ(math::Color(0.8f, 0.8f, 0.8f, 1),
           _light->Data().Diffuse());
-      EXPECT_EQ(ignition::math::Color(0.2f, 0.2f, 0.2f, 1),
+      EXPECT_EQ(math::Color(0.2f, 0.2f, 0.2f, 1),
           _light->Data().Specular());
       EXPECT_DOUBLE_EQ(1000, _light->Data().AttenuationRange());
       EXPECT_DOUBLE_EQ(0.9, _light->Data().ConstantAttenuationFactor());
       EXPECT_DOUBLE_EQ(0.01, _light->Data().LinearAttenuationFactor());
       EXPECT_DOUBLE_EQ(0.001, _light->Data().QuadraticAttenuationFactor());
-      EXPECT_EQ(ignition::math::Vector3d(-0.5, 0.1, -0.9),
+      EXPECT_EQ(math::Vector3d(-0.5, 0.1, -0.9),
           _light->Data().Direction());
       return true;
     });
@@ -541,10 +541,10 @@ TEST_P(SimulationRunnerTest, CreateLights)
   // Check worlds
   unsigned int worldCount{0};
   Entity worldEntity = kNullEntity;
-  runner.EntityCompMgr().Each<components::World,
+  runner.EntityCompMgr().Each<World,
                             components::Name>(
     [&](const Entity &_entity,
-        const components::World *_world,
+        const World *_world,
         const components::Name *_name)->bool
     {
       EXPECT_NE(nullptr, _world);
@@ -564,14 +564,14 @@ TEST_P(SimulationRunnerTest, CreateLights)
   // Check model
   unsigned int modelCount{0};
   Entity sphModelEntity = kNullEntity;
-  runner.EntityCompMgr().Each<components::Model,
-                            components::Pose,
-                            components::ParentEntity,
+  runner.EntityCompMgr().Each<Model,
+                            Pose,
+                            ParentEntity,
                             components::Name>(
     [&](const Entity &_entity,
-        const components::Model *_model,
-        const components::Pose *_pose,
-        const components::ParentEntity *_parent,
+        const Model *_model,
+        const Pose *_pose,
+        const ParentEntity *_parent,
         const components::Name *_name)->bool
     {
       EXPECT_NE(nullptr, _model);
@@ -582,7 +582,7 @@ TEST_P(SimulationRunnerTest, CreateLights)
       modelCount++;
 
       EXPECT_EQ(worldEntity, _parent->Data());
-      EXPECT_EQ(ignition::math::Pose3d(0, 0, 0, 0, 0, 0),
+      EXPECT_EQ(math::Pose3d(0, 0, 0, 0, 0, 0),
           _pose->Data());
       EXPECT_EQ("sphere", _name->Data());
       sphModelEntity = _entity;
@@ -596,14 +596,14 @@ TEST_P(SimulationRunnerTest, CreateLights)
   // Check link
   unsigned int linkCount{0};
   Entity sphLinkEntity = kNullEntity;
-  runner.EntityCompMgr().Each<components::Link,
-                            components::Pose,
-                            components::ParentEntity,
+  runner.EntityCompMgr().Each<Link,
+                            Pose,
+                            ParentEntity,
                             components::Name>(
     [&](const Entity &_entity,
-        const components::Link *_link,
-        const components::Pose *_pose,
-        const components::ParentEntity *_parent,
+        const Link *_link,
+        const Pose *_pose,
+        const ParentEntity *_parent,
         const components::Name *_name)->bool
     {
       EXPECT_NE(nullptr, _link);
@@ -613,7 +613,7 @@ TEST_P(SimulationRunnerTest, CreateLights)
 
       linkCount++;
 
-      EXPECT_EQ(ignition::math::Pose3d(0.0, 0.0, 0.0, 0, 0, 0),
+      EXPECT_EQ(math::Pose3d(0.0, 0.0, 0.0, 0, 0, 0),
           _pose->Data());
       EXPECT_EQ("sphere_link", _name->Data());
       EXPECT_EQ(sphModelEntity, _parent->Data());
@@ -627,18 +627,18 @@ TEST_P(SimulationRunnerTest, CreateLights)
 
   // Check visuals
   unsigned int visualCount{0};
-  runner.EntityCompMgr().Each<components::Visual,
-                            components::Geometry,
+  runner.EntityCompMgr().Each<Visual,
+                            Geometry,
                             components::Material,
-                            components::Pose,
-                            components::ParentEntity,
+                            Pose,
+                            ParentEntity,
                             components::Name>(
     [&](const Entity &/*_entity*/,
-        const components::Visual *_visual,
-        const components::Geometry *_geometry,
+        const Visual *_visual,
+        const Geometry *_geometry,
         const components::Material *_material,
-        const components::Pose *_pose,
-        const components::ParentEntity *_parent,
+        const Pose *_pose,
+        const ParentEntity *_parent,
         const components::Name *_name)->bool
     {
       EXPECT_NE(nullptr, _visual);
@@ -650,7 +650,7 @@ TEST_P(SimulationRunnerTest, CreateLights)
 
       visualCount++;
 
-      EXPECT_EQ(ignition::math::Pose3d(0.0, 0.0, 0.0, 0, 0, 0),
+      EXPECT_EQ(math::Pose3d(0.0, 0.0, 0.0, 0, 0, 0),
           _pose->Data());
 
       EXPECT_EQ("sphere_visual", _name->Data());
@@ -671,14 +671,14 @@ TEST_P(SimulationRunnerTest, CreateLights)
 
   // Check lights
   unsigned int lightCount{0};
-  runner.EntityCompMgr().Each<components::Light,
-                            components::Pose,
-                            components::ParentEntity,
+  runner.EntityCompMgr().Each<Light,
+                            Pose,
+                            ParentEntity,
                             components::Name>(
     [&](const Entity &/*_entity*/,
-        const components::Light *_light,
-        const components::Pose *_pose,
-        const components::ParentEntity *_parent,
+        const Light *_light,
+        const Pose *_pose,
+        const ParentEntity *_parent,
         const components::Name *_name)->bool
     {
       EXPECT_NE(nullptr, _light);
@@ -691,19 +691,19 @@ TEST_P(SimulationRunnerTest, CreateLights)
       // light attached to link
       if (lightCount == 1u)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.0, 0.0, 1.0, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.0, 0.0, 1.0, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("link_light_point", _name->Data());
         EXPECT_EQ(sphLinkEntity, _parent->Data());
         EXPECT_EQ("link_light_point", _light->Data().Name());
         EXPECT_EQ(sdf::LightType::POINT, _light->Data().Type());
-        EXPECT_EQ(ignition::math::Pose3d(0, 0, 1, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0, 0, 1, 0, 0, 0),
             _light->Data().RawPose());
         EXPECT_EQ(std::string(), _light->Data().PoseRelativeTo());
         EXPECT_FALSE(_light->Data().CastShadows());
-        EXPECT_EQ(ignition::math::Color(0.0f, 0.0f, 1.0f, 1),
+        EXPECT_EQ(math::Color(0.0f, 0.0f, 1.0f, 1),
             _light->Data().Diffuse());
-        EXPECT_EQ(ignition::math::Color(0.1f, 0.1f, 0.1f, 1),
+        EXPECT_EQ(math::Color(0.1f, 0.1f, 0.1f, 1),
             _light->Data().Specular());
         EXPECT_DOUBLE_EQ(2, _light->Data().AttenuationRange());
         EXPECT_DOUBLE_EQ(0.05, _light->Data().ConstantAttenuationFactor());
@@ -713,43 +713,43 @@ TEST_P(SimulationRunnerTest, CreateLights)
       // directional light in the world
       else if (lightCount == 2u)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.0, 0.0, 10, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.0, 0.0, 10, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("directional", _name->Data());
         EXPECT_EQ(worldEntity, _parent->Data());
         EXPECT_EQ("directional", _light->Data().Name());
         EXPECT_EQ(sdf::LightType::DIRECTIONAL, _light->Data().Type());
-        EXPECT_EQ(ignition::math::Pose3d(0, 0, 10, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0, 0, 10, 0, 0, 0),
             _light->Data().RawPose());
         EXPECT_EQ(std::string(), _light->Data().PoseRelativeTo());
         EXPECT_TRUE(_light->Data().CastShadows());
-        EXPECT_EQ(ignition::math::Color(0.8f, 0.8f, 0.8f, 1),
+        EXPECT_EQ(math::Color(0.8f, 0.8f, 0.8f, 1),
             _light->Data().Diffuse());
-        EXPECT_EQ(ignition::math::Color(0.2f, 0.2f, 0.2f, 1),
+        EXPECT_EQ(math::Color(0.2f, 0.2f, 0.2f, 1),
             _light->Data().Specular());
         EXPECT_DOUBLE_EQ(100, _light->Data().AttenuationRange());
         EXPECT_DOUBLE_EQ(0.9, _light->Data().ConstantAttenuationFactor());
         EXPECT_DOUBLE_EQ(0.01, _light->Data().LinearAttenuationFactor());
         EXPECT_DOUBLE_EQ(0.001, _light->Data().QuadraticAttenuationFactor());
-        EXPECT_EQ(ignition::math::Vector3d(0.5, 0.2, -0.9),
+        EXPECT_EQ(math::Vector3d(0.5, 0.2, -0.9),
             _light->Data().Direction());
       }
       // point light in the world
       else if (lightCount == 3u)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.0, -1.5, 3, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.0, -1.5, 3, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("point", _name->Data());
         EXPECT_EQ(worldEntity, _parent->Data());
         EXPECT_EQ("point", _light->Data().Name());
         EXPECT_EQ(sdf::LightType::POINT, _light->Data().Type());
-        EXPECT_EQ(ignition::math::Pose3d(0, -1.5, 3, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0, -1.5, 3, 0, 0, 0),
             _light->Data().RawPose());
         EXPECT_EQ(std::string(), _light->Data().PoseRelativeTo());
         EXPECT_FALSE(_light->Data().CastShadows());
-        EXPECT_EQ(ignition::math::Color(1.0f, 0.0f, 0.0f, 1),
+        EXPECT_EQ(math::Color(1.0f, 0.0f, 0.0f, 1),
             _light->Data().Diffuse());
-        EXPECT_EQ(ignition::math::Color(0.1f, 0.1f, 0.1f, 1),
+        EXPECT_EQ(math::Color(0.1f, 0.1f, 0.1f, 1),
             _light->Data().Specular());
         EXPECT_DOUBLE_EQ(4, _light->Data().AttenuationRange());
         EXPECT_DOUBLE_EQ(0.2, _light->Data().ConstantAttenuationFactor());
@@ -759,25 +759,25 @@ TEST_P(SimulationRunnerTest, CreateLights)
       // spot light in the world
       else if (lightCount == 4u)
       {
-        EXPECT_EQ(ignition::math::Pose3d(0.0, 1.5, 3, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0.0, 1.5, 3, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("spot", _name->Data());
         EXPECT_EQ(worldEntity, _parent->Data());
         EXPECT_EQ("spot", _light->Data().Name());
         EXPECT_EQ(sdf::LightType::SPOT, _light->Data().Type());
-        EXPECT_EQ(ignition::math::Pose3d(0, 1.5, 3, 0, 0, 0),
+        EXPECT_EQ(math::Pose3d(0, 1.5, 3, 0, 0, 0),
             _light->Data().RawPose());
         EXPECT_EQ(std::string(), _light->Data().PoseRelativeTo());
         EXPECT_FALSE(_light->Data().CastShadows());
-        EXPECT_EQ(ignition::math::Color(0.0f, 1.0f, 0.0f, 1),
+        EXPECT_EQ(math::Color(0.0f, 1.0f, 0.0f, 1),
             _light->Data().Diffuse());
-        EXPECT_EQ(ignition::math::Color(0.2f, 0.2f, 0.2f, 1),
+        EXPECT_EQ(math::Color(0.2f, 0.2f, 0.2f, 1),
             _light->Data().Specular());
         EXPECT_DOUBLE_EQ(5, _light->Data().AttenuationRange());
         EXPECT_DOUBLE_EQ(0.3, _light->Data().ConstantAttenuationFactor());
         EXPECT_DOUBLE_EQ(0.4, _light->Data().LinearAttenuationFactor());
         EXPECT_DOUBLE_EQ(0.001, _light->Data().QuadraticAttenuationFactor());
-        EXPECT_EQ(ignition::math::Vector3d(0.0, 0.0, -1.0),
+        EXPECT_EQ(math::Vector3d(0.0, 0.0, -1.0),
             _light->Data().Direction());
         EXPECT_DOUBLE_EQ(0.1, _light->Data().SpotInnerAngle().Radian());
         EXPECT_DOUBLE_EQ(0.5, _light->Data().SpotOuterAngle().Radian());
@@ -805,34 +805,34 @@ TEST_P(SimulationRunnerTest, CreateJointEntities)
 
   // Check component types
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::World::typeId));
+      World::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::CanonicalLink::typeId));
+      CanonicalLink::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::Link::typeId));
+      Link::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::Joint::typeId));
+      Joint::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::JointAxis::typeId));
+      JointAxis::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::JointType::typeId));
+      JointType::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::ChildLinkName::typeId));
+      ChildLinkName::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::ParentLinkName::typeId));
+      ParentLinkName::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::ParentEntity::typeId));
+      ParentEntity::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::Pose::typeId));
+      Pose::typeId));
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(
-      components::Name::typeId));
+      Name::typeId));
 
   const sdf::Model *model = root.WorldByIndex(0)->ModelByIndex(1);
 
   // Check canonical links
   unsigned int canonicalLinkCount{0};
-  runner.EntityCompMgr().Each<components::CanonicalLink>(
-    [&](const Entity &, const components::CanonicalLink *)->bool
+  runner.EntityCompMgr().Each<CanonicalLink>(
+    [&](const Entity &, const CanonicalLink *)->bool
     {
       canonicalLinkCount++;
       return true;
@@ -852,11 +852,11 @@ TEST_P(SimulationRunnerTest, CreateJointEntities)
   };
 
   auto testJoint = [&testAxis](const sdf::Joint *_joint,
-      const components::JointAxis *_axis,
-      const components::JointAxis2 *_axis2,
-      const components::ParentLinkName *_parentLinkName,
-      const components::ChildLinkName *_childLinkName,
-      const components::Pose *_pose,
+      const JointAxis *_axis,
+      const JointAxis2 *_axis2,
+      const ParentLinkName *_parentLinkName,
+      const ChildLinkName *_childLinkName,
+      const Pose *_pose,
       const components::Name *_name,
       bool _checkAxis = true,
       bool _checkAxis2 = false)
@@ -891,25 +891,25 @@ TEST_P(SimulationRunnerTest, CreateJointEntities)
   };
 
   std::set<sdf::JointType> jointTypes;
-  runner.EntityCompMgr().Each<components::Joint,
-                            components::JointType,
-                            components::ParentLinkName,
-                            components::ChildLinkName,
-                            components::Pose,
+  runner.EntityCompMgr().Each<Joint,
+                            JointType,
+                            ParentLinkName,
+                            ChildLinkName,
+                            Pose,
                             components::Name>(
     [&](const Entity &_entity,
-        const components::Joint * /*_joint*/,
-        const components::JointType *_jointType,
-        const components::ParentLinkName *_parentLinkName,
-        const components::ChildLinkName *_childLinkName,
-        const components::Pose *_pose,
+        const Joint * /*_joint*/,
+        const JointType *_jointType,
+        const ParentLinkName *_parentLinkName,
+        const ChildLinkName *_childLinkName,
+        const Pose *_pose,
         const components::Name *_name)->bool
     {
       jointTypes.insert(_jointType->Data());
       auto axis =
-          runner.EntityCompMgr().Component<components::JointAxis>(_entity);
+          runner.EntityCompMgr().Component<JointAxis>(_entity);
       auto axis2 =
-          runner.EntityCompMgr().Component<components::JointAxis2>(_entity);
+          runner.EntityCompMgr().Component<JointAxis2>(_entity);
 
       const sdf::Joint *joint = model->JointByName(_name->Data());
 
@@ -953,7 +953,7 @@ TEST_P(SimulationRunnerTest, Time)
   EXPECT_EQ(0u, runner.CurrentInfo().iterations);
   EXPECT_EQ(0ms, runner.CurrentInfo().simTime);
   EXPECT_EQ(0ms, runner.CurrentInfo().dt);
-  EXPECT_EQ(1ms, runner.UpdatePeriod());
+  EXPECT_EQ(0ms, runner.UpdatePeriod());
   EXPECT_EQ(1ms, runner.StepSize());
 
   runner.SetPaused(false);
@@ -966,7 +966,7 @@ TEST_P(SimulationRunnerTest, Time)
   EXPECT_EQ(100u, runner.CurrentInfo().iterations);
   EXPECT_EQ(100ms, runner.CurrentInfo().simTime);
   EXPECT_EQ(1ms, runner.CurrentInfo().dt);
-  EXPECT_EQ(1ms, runner.UpdatePeriod());
+  EXPECT_EQ(0ms, runner.UpdatePeriod());
   EXPECT_EQ(1ms, runner.StepSize());
 
   int sleep = 0;
@@ -987,7 +987,7 @@ TEST_P(SimulationRunnerTest, Time)
   EXPECT_EQ(200u, runner.CurrentInfo().iterations);
   EXPECT_EQ(300ms, runner.CurrentInfo().simTime);
   EXPECT_EQ(2ms, runner.CurrentInfo().dt);
-  EXPECT_EQ(1ms, runner.UpdatePeriod());
+  EXPECT_EQ(0ms, runner.UpdatePeriod());
   EXPECT_EQ(2ms, runner.StepSize());
 
   sleep = 0;
@@ -1007,7 +1007,7 @@ TEST_P(SimulationRunnerTest, Time)
   EXPECT_EQ(200u, runner.CurrentInfo().iterations);
   EXPECT_EQ(300ms, runner.CurrentInfo().simTime);
   EXPECT_EQ(2ms, runner.CurrentInfo().dt);
-  EXPECT_EQ(1ms, runner.UpdatePeriod());
+  EXPECT_EQ(0ms, runner.UpdatePeriod());
   EXPECT_EQ(2ms, runner.StepSize());
 
   // Verify info published to /clock topic
@@ -1025,7 +1025,7 @@ TEST_P(SimulationRunnerTest, Time)
   EXPECT_EQ(500ms, runner.CurrentInfo().simTime)
     << runner.CurrentInfo().simTime.count();
   EXPECT_EQ(2ms, runner.CurrentInfo().dt);
-  EXPECT_EQ(1ms, runner.UpdatePeriod());
+  EXPECT_EQ(0ms, runner.UpdatePeriod());
   EXPECT_EQ(2ms, runner.StepSize());
 
   sleep = 0;
@@ -1068,9 +1068,9 @@ TEST_P(SimulationRunnerTest, LoadPlugins)
 
   // Get world entity
   Entity worldId{kNullEntity};
-  runner.EntityCompMgr().Each<ignition::gazebo::components::World>([&](
-      const ignition::gazebo::Entity &_entity,
-      const ignition::gazebo::components::World *_world)->bool
+  runner.EntityCompMgr().Each<World>([&](
+      const Entity &_entity,
+      const World *_world)->bool
       {
         EXPECT_NE(nullptr, _world);
         worldId = _entity;
@@ -1080,9 +1080,9 @@ TEST_P(SimulationRunnerTest, LoadPlugins)
 
   // Get model entity
   Entity modelId{kNullEntity};
-  runner.EntityCompMgr().Each<ignition::gazebo::components::Model>([&](
-      const ignition::gazebo::Entity &_entity,
-      const ignition::gazebo::components::Model *_model)->bool
+  runner.EntityCompMgr().Each<Model>([&](
+      const Entity &_entity,
+      const Model *_model)->bool
       {
         EXPECT_NE(nullptr, _model);
         modelId = _entity;
@@ -1092,9 +1092,9 @@ TEST_P(SimulationRunnerTest, LoadPlugins)
 
   // Get sensor entity
   Entity sensorId{kNullEntity};
-  runner.EntityCompMgr().Each<ignition::gazebo::components::Sensor>([&](
-      const ignition::gazebo::Entity &_entity,
-      const ignition::gazebo::components::Sensor *_sensor)->bool
+  runner.EntityCompMgr().Each<Sensor>([&](
+      const Entity &_entity,
+      const Sensor *_sensor)->bool
       {
         EXPECT_NE(nullptr, _sensor);
         sensorId = _entity;
@@ -1104,7 +1104,7 @@ TEST_P(SimulationRunnerTest, LoadPlugins)
 
   // Check component registered by world plugin
   std::string worldComponentName{"WorldPluginComponent"};
-  auto worldComponentId = ignition::common::hash64(worldComponentName);
+  auto worldComponentId = common::hash64(worldComponentName);
 
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(worldComponentId));
   EXPECT_TRUE(runner.EntityCompMgr().EntityHasComponentType(worldId,
@@ -1112,7 +1112,7 @@ TEST_P(SimulationRunnerTest, LoadPlugins)
 
   // Check component registered by model plugin
   std::string modelComponentName{"ModelPluginComponent"};
-  auto modelComponentId = ignition::common::hash64(modelComponentName);
+  auto modelComponentId = common::hash64(modelComponentName);
 
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(modelComponentId));
   EXPECT_TRUE(runner.EntityCompMgr().EntityHasComponentType(modelId,
@@ -1120,7 +1120,7 @@ TEST_P(SimulationRunnerTest, LoadPlugins)
 
   // Check component registered by sensor plugin
   std::string sensorComponentName{"SensorPluginComponent"};
-  auto sensorComponentId = ignition::common::hash64(sensorComponentName);
+  auto sensorComponentId = common::hash64(sensorComponentName);
 
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(sensorComponentId));
   EXPECT_TRUE(runner.EntityCompMgr().EntityHasComponentType(sensorId,
@@ -1133,9 +1133,9 @@ TEST_P(SimulationRunnerTest, LoadPlugins)
   // reproduce? Maybe we need to test unloading plugins, but we have no API for
   // it yet.
   #if defined (__clang__)
-    components::Factory::Instance()->Unregister(worldComponentId);
-    components::Factory::Instance()->Unregister(modelComponentId);
-    components::Factory::Instance()->Unregister(sensorComponentId);
+    Factory::Instance()->Unregister(worldComponentId);
+    Factory::Instance()->Unregister(modelComponentId);
+    Factory::Instance()->Unregister(sensorComponentId);
   #endif
 }
 
@@ -1150,7 +1150,7 @@ TEST_P(SimulationRunnerTest, LoadServerNoPlugins)
   // ServerConfig will fall back to environment variable
   auto config = common::joinPaths(PROJECT_SOURCE_PATH,
     "test", "worlds", "server_valid2.config");
-  ASSERT_EQ(true, common::setenv(gazebo::kServerConfigPathEnv, config));
+  ASSERT_EQ(true, common::setenv(kServerConfigPathEnv, config));
   ServerConfig serverConfig;
 
   // Create simulation runner
@@ -1190,9 +1190,9 @@ TEST_P(SimulationRunnerTest, LoadServerConfigPlugins)
 
   // Get world entity
   Entity worldId{kNullEntity};
-  runner.EntityCompMgr().Each<ignition::gazebo::components::World>([&](
-      const ignition::gazebo::Entity &_entity,
-      const ignition::gazebo::components::World *_world)->bool
+  runner.EntityCompMgr().Each<World>([&](
+      const Entity &_entity,
+      const World *_world)->bool
       {
         EXPECT_NE(nullptr, _world);
         worldId = _entity;
@@ -1202,9 +1202,9 @@ TEST_P(SimulationRunnerTest, LoadServerConfigPlugins)
 
   // Get model entity
   Entity modelId{kNullEntity};
-  runner.EntityCompMgr().Each<ignition::gazebo::components::Model>([&](
-      const ignition::gazebo::Entity &_entity,
-      const ignition::gazebo::components::Model *_model)->bool
+  runner.EntityCompMgr().Each<Model>([&](
+      const Entity &_entity,
+      const Model *_model)->bool
       {
         EXPECT_NE(nullptr, _model);
         modelId = _entity;
@@ -1214,9 +1214,9 @@ TEST_P(SimulationRunnerTest, LoadServerConfigPlugins)
 
   // Get sensor entity
   Entity sensorId{kNullEntity};
-  runner.EntityCompMgr().Each<ignition::gazebo::components::Sensor>([&](
-      const ignition::gazebo::Entity &_entity,
-      const ignition::gazebo::components::Sensor *_sensor)->bool
+  runner.EntityCompMgr().Each<Sensor>([&](
+      const Entity &_entity,
+      const Sensor *_sensor)->bool
       {
         EXPECT_NE(nullptr, _sensor);
         sensorId = _entity;
@@ -1226,7 +1226,7 @@ TEST_P(SimulationRunnerTest, LoadServerConfigPlugins)
 
   // Check component registered by world plugin
   std::string worldComponentName{"WorldPluginComponent"};
-  auto worldComponentId = ignition::common::hash64(worldComponentName);
+  auto worldComponentId = common::hash64(worldComponentName);
 
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(worldComponentId));
   EXPECT_TRUE(runner.EntityCompMgr().EntityHasComponentType(worldId,
@@ -1234,7 +1234,7 @@ TEST_P(SimulationRunnerTest, LoadServerConfigPlugins)
 
   // Check component registered by model plugin
   std::string modelComponentName{"ModelPluginComponent"};
-  auto modelComponentId = ignition::common::hash64(modelComponentName);
+  auto modelComponentId = common::hash64(modelComponentName);
 
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(modelComponentId));
   EXPECT_TRUE(runner.EntityCompMgr().EntityHasComponentType(modelId,
@@ -1242,7 +1242,7 @@ TEST_P(SimulationRunnerTest, LoadServerConfigPlugins)
 
   // Check component registered by sensor plugin
   std::string sensorComponentName{"SensorPluginComponent"};
-  auto sensorComponentId = ignition::common::hash64(sensorComponentName);
+  auto sensorComponentId = common::hash64(sensorComponentName);
 
   EXPECT_TRUE(runner.EntityCompMgr().HasComponentType(sensorComponentId));
   EXPECT_TRUE(runner.EntityCompMgr().EntityHasComponentType(sensorId,
@@ -1255,9 +1255,9 @@ TEST_P(SimulationRunnerTest, LoadServerConfigPlugins)
   // reproduce? Maybe we need to test unloading plugins, but we have no API for
   // it yet.
   #if defined (__clang__)
-    components::Factory::Instance()->Unregister(worldComponentId);
-    components::Factory::Instance()->Unregister(modelComponentId);
-    components::Factory::Instance()->Unregister(sensorComponentId);
+    Factory::Instance()->Unregister(worldComponentId);
+    Factory::Instance()->Unregister(modelComponentId);
+    Factory::Instance()->Unregister(sensorComponentId);
   #endif
 }
 
@@ -1273,13 +1273,13 @@ TEST_P(SimulationRunnerTest, LoadPluginsDefault)
   // The user may have modified their local config.
   auto config = common::joinPaths(PROJECT_SOURCE_PATH,
     "include", "ignition", "gazebo", "server.config");
-  ASSERT_TRUE(common::setenv(gazebo::kServerConfigPathEnv, config));
+  ASSERT_TRUE(common::setenv(kServerConfigPathEnv, config));
 
   // Create simulation runner
   auto systemLoader = std::make_shared<SystemLoader>();
   SimulationRunner runner(rootWithout.WorldByIndex(0), systemLoader);
   ASSERT_EQ(3u, runner.SystemCount());
-  common::unsetenv(gazebo::kServerConfigPathEnv);
+  common::unsetenv(kServerConfigPathEnv);
 }
 
 /////////////////////////////////////////////////
@@ -1298,24 +1298,24 @@ TEST_P(SimulationRunnerTest, LoadPluginsEvent)
 
   // Get model entities
   auto boxEntity = runner.EntityCompMgr().EntityByComponents(
-      ignition::gazebo::components::Model(),
-      ignition::gazebo::components::Name("box"));
+      Model(),
+      components::Name("box"));
   EXPECT_NE(kNullEntity, boxEntity);
 
   auto sphereEntity = runner.EntityCompMgr().EntityByComponents(
-      ignition::gazebo::components::Model(),
-      ignition::gazebo::components::Name("sphere"));
+      Model(),
+      components::Name("sphere"));
   EXPECT_NE(kNullEntity, sphereEntity);
 
   auto cylinderEntity = runner.EntityCompMgr().EntityByComponents(
-      ignition::gazebo::components::Model(),
-      ignition::gazebo::components::Name("cylinder"));
+      Model(),
+      components::Name("cylinder"));
   EXPECT_NE(kNullEntity, cylinderEntity);
 
   // We can't access the type registered by the plugin unless we link against
   // it, but we know its name to check
   std::string componentName{"ModelPluginComponent"};
-  auto componentId = ignition::common::hash64(componentName);
+  auto componentId = common::hash64(componentName);
 
   // Check there's no double component
   EXPECT_FALSE(runner.EntityCompMgr().HasComponentType(componentId));
