@@ -216,7 +216,7 @@ ResourceSpawner::ResourceSpawner()
   ignition::gui::App()->Engine()->rootContext()->setContextProperty(
       "OwnerList", &this->dataPtr->ownerModel);
   this->dataPtr->fuelClient =
-    std::make_unique<ignition::fuel_tools::FuelClient>();
+    std::make_unique<fuel_tools::FuelClient>();
 }
 
 /////////////////////////////////////////////////
@@ -481,7 +481,7 @@ void ResourceSpawner::OnDownloadFuelResource(const QString &_path,
   // Set the waiting cursor while the resource downloads
   QGuiApplication::setOverrideCursor(Qt::WaitCursor);
   if (this->dataPtr->fuelClient->DownloadModel(
-        ignition::common::URI(_path.toStdString()), localPath))
+        common::URI(_path.toStdString()), localPath))
   {
     // Successful download, set thumbnail
     std::string thumbnailPath = common::joinPaths(localPath, "thumbnails");
@@ -563,7 +563,7 @@ void ResourceSpawner::LoadConfig(const tinyxml2::XMLElement *)
     std::set<std::string> ownerSet;
     for (auto const &server : servers)
     {
-      std::vector<ignition::fuel_tools::ModelIdentifier> models;
+      std::vector<fuel_tools::ModelIdentifier> models;
       for (auto iter = this->dataPtr->fuelClient->Models(server); iter; ++iter)
       {
         models.push_back(iter->Identification());
@@ -583,10 +583,10 @@ void ResourceSpawner::LoadConfig(const tinyxml2::XMLElement *)
         // If the resource is cached, we can go ahead and populate the
         // respective information
         if (this->dataPtr->fuelClient->CachedModel(
-              ignition::common::URI(id.UniqueName()), path))
+              common::URI(id.UniqueName()), path))
         {
           resource.isDownloaded = true;
-          resource.sdfPath = ignition::common::joinPaths(path, "model.sdf");
+          resource.sdfPath = common::joinPaths(path, "model.sdf");
           std::string thumbnailPath = common::joinPaths(path, "thumbnails");
           this->SetThumbnail(thumbnailPath, resource);
         }
@@ -632,5 +632,5 @@ void ResourceSpawner::OnResourceSpawn(const QString &_sdfPath)
 }
 
 // Register this plugin
-IGNITION_ADD_PLUGIN(ignition::gazebo::ResourceSpawner,
+IGNITION_ADD_PLUGIN(ResourceSpawner,
     ignition::gui::Plugin)
