@@ -39,7 +39,7 @@ class ignition::gazebo::systems::JointPositionControllerPrivate
 {
   /// \brief Callback for position subscription
   /// \param[in] _msg Position message
-  public: void OnCmdPos(const ignition::msgs::Double &_msg);
+  public: void OnCmdPos(const msgs::Double &_msg);
 
   /// \brief Ignition communication node.
   public: transport::Node node;
@@ -60,7 +60,7 @@ class ignition::gazebo::systems::JointPositionControllerPrivate
   public: Model model{kNullEntity};
 
   /// \brief Position PID controller.
-  public: ignition::math::PID posPid;
+  public: math::PID posPid;
 
   /// \brief Joint index to be used.
   public: unsigned int jointIndex = 0u;
@@ -172,8 +172,8 @@ void JointPositionController::Configure(const Entity &_entity,
 
 //////////////////////////////////////////////////
 void JointPositionController::PreUpdate(
-    const ignition::gazebo::UpdateInfo &_info,
-    ignition::gazebo::EntityComponentManager &_ecm)
+    const UpdateInfo &_info,
+    EntityComponentManager &_ecm)
 {
   IGN_PROFILE("JointPositionController::PreUpdate");
 
@@ -192,8 +192,17 @@ void JointPositionController::PreUpdate(
         this->dataPtr->model.JointByName(_ecm, this->dataPtr->jointName);
   }
 
+  // If the joint is still not found then warn the user, they may have entered
+  // the wrong joint name.
   if (this->dataPtr->jointEntity == kNullEntity)
+  {
+    static bool warned = false;
+    if(!warned)
+      ignerr << "Could not find joint with name ["
+        << this->dataPtr->jointName <<"]\n";
+    warned = true;
     return;
+  }
 
   // Nothing left to do if paused.
   if (_info.paused)
@@ -260,7 +269,7 @@ void JointPositionControllerPrivate::OnCmdPos(const msgs::Double &_msg)
 }
 
 IGNITION_ADD_PLUGIN(JointPositionController,
-                    ignition::gazebo::System,
+                    System,
                     JointPositionController::ISystemConfigure,
                     JointPositionController::ISystemPreUpdate)
 
