@@ -105,16 +105,16 @@ class ignition::gazebo::systems::LiftDragPrivate
 
   /// \brief center of pressure in link local coordinates with respect to the
   /// link's center of mass
-  public: ignition::math::Vector3d cp = math::Vector3d::Zero;
+  public: math::Vector3d cp = math::Vector3d::Zero;
 
   /// \brief Normally, this is taken as a direction parallel to the chord
   /// of the airfoil in zero angle of attack forward flight.
-  public: ignition::math::Vector3d forward = math::Vector3d::UnitX;
+  public: math::Vector3d forward = math::Vector3d::UnitX;
 
   /// \brief A vector in the lift/drag plane, perpendicular to the forward
   /// vector. Inflow velocity orthogonal to forward and upward vectors
   /// is considered flow in the wing sweep direction.
-  public: ignition::math::Vector3d upward = math::Vector3d::UnitZ;
+  public: math::Vector3d upward = math::Vector3d::UnitZ;
 
   /// \brief how much to change CL per radian of control surface joint
   /// value.
@@ -153,15 +153,15 @@ void LiftDragPrivate::Load(const EntityComponentManager &_ecm,
       this->radialSymmetry).first;
   this->area = _sdf->Get<double>("area", this->area).first;
   this->alpha0 = _sdf->Get<double>("a0", this->alpha0).first;
-  this->cp = _sdf->Get<ignition::math::Vector3d>("cp", this->cp).first;
+  this->cp = _sdf->Get<math::Vector3d>("cp", this->cp).first;
 
   // blade forward (-drag) direction in link frame
   this->forward =
-      _sdf->Get<ignition::math::Vector3d>("forward", this->forward).first;
+      _sdf->Get<math::Vector3d>("forward", this->forward).first;
   this->forward.Normalize();
 
   // blade upward (+lift) direction in link frame
-  this->upward = _sdf->Get<ignition::math::Vector3d>(
+  this->upward = _sdf->Get<math::Vector3d>(
       "upward", this->upward) .first;
   this->upward.Normalize();
 
@@ -246,12 +246,12 @@ void LiftDragPrivate::Update(EntityComponentManager &_ecm)
   // rotate forward and upward vectors into world frame
   const auto forwardI = pose.Rot().RotateVector(this->forward);
 
-  ignition::math::Vector3d upwardI;
+  math::Vector3d upwardI;
   if (this->radialSymmetry)
   {
     // use inflow velocity to determine upward direction
     // which is the component of inflow perpendicular to forward direction.
-    ignition::math::Vector3d tmp = forwardI.Cross(velI);
+    math::Vector3d tmp = forwardI.Cross(velI);
     upwardI = forwardI.Cross(tmp).Normalize();
   }
   else
@@ -265,7 +265,7 @@ void LiftDragPrivate::Update(EntityComponentManager &_ecm)
   const double minRatio = -1.0;
   const double maxRatio = 1.0;
   // check sweep (angle between velI and lift-drag-plane)
-  double sinSweepAngle = ignition::math::clamp(
+  double sinSweepAngle = math::clamp(
       spanwiseI.Dot(velI), minRatio, maxRatio);
 
   // get cos from trig identity
@@ -305,7 +305,7 @@ void LiftDragPrivate::Update(EntityComponentManager &_ecm)
   // given upwardI and liftI are both unit vectors, we can drop the denominator
   //   cos(theta) = a.Dot(b)
   const double cosAlpha =
-      ignition::math::clamp(liftI.Dot(upwardI), minRatio, maxRatio);
+      math::clamp(liftI.Dot(upwardI), minRatio, maxRatio);
 
   // Is alpha positive or negative? Test:
   // forwardI points toward zero alpha
@@ -354,7 +354,7 @@ void LiftDragPrivate::Update(EntityComponentManager &_ecm)
   }
 
   // compute lift force at cp
-  ignition::math::Vector3d lift = cl * q * this->area * liftI;
+  math::Vector3d lift = cl * q * this->area * liftI;
 
   // compute cd at cp, check for stall, correct for sweep
   double cd;
@@ -377,7 +377,7 @@ void LiftDragPrivate::Update(EntityComponentManager &_ecm)
   cd = std::fabs(cd);
 
   // drag at cp
-  ignition::math::Vector3d drag = cd * q * this->area * dragDirection;
+  math::Vector3d drag = cd * q * this->area * dragDirection;
 
   // compute cm at cp, check for stall, correct for sweep
   double cm;
@@ -406,12 +406,12 @@ void LiftDragPrivate::Update(EntityComponentManager &_ecm)
 
   // compute moment (torque) at cp
   // spanwiseI used to be momentDirection
-  ignition::math::Vector3d moment = cm * q * this->area * spanwiseI;
+  math::Vector3d moment = cm * q * this->area * spanwiseI;
 
 
   // force and torque about cg in world frame
-  ignition::math::Vector3d force = lift + drag;
-  ignition::math::Vector3d torque = moment;
+  math::Vector3d force = lift + drag;
+  math::Vector3d torque = moment;
   // Correct for nan or inf
   force.Correct();
   this->cp.Correct();
@@ -523,7 +523,7 @@ void LiftDrag::PreUpdate(const UpdateInfo &_info, EntityComponentManager &_ecm)
 }
 
 IGNITION_ADD_PLUGIN(LiftDrag,
-                    ignition::gazebo::System,
+                    System,
                     LiftDrag::ISystemConfigure,
                     LiftDrag::ISystemPreUpdate)
 
