@@ -78,7 +78,7 @@ class ignition::gazebo::systems::LogicalAudioSensorPluginPrivate
                const logical_audio::SourcePlayInfo &_sourcePlayInfo);
 
   /// \brief Node used to create publishers and services
-  public: ignition::transport::Node node;
+  public: transport::Node node;
 
   /// \brief A flag used to initialize a source's playing information
   /// before starting simulation.
@@ -97,7 +97,7 @@ class ignition::gazebo::systems::LogicalAudioSensorPluginPrivate
   /// (an entity can have multiple microphones attached to it).
   /// The value is the microphone's detection publisher.
   public: std::unordered_map<Entity,
-            ignition::transport::Node::Publisher> micEntities;
+            transport::Node::Publisher> micEntities;
 
   /// \brief A mutex used to ensure that the play source service call does
   /// not interfere with the source's state in the PreUpdate step.
@@ -240,7 +240,7 @@ void LogicalAudioSensorPlugin::PostUpdate(const UpdateInfo &_info,
           // publish the source that the microphone heard, along with the
           // volume level the microphone detected. The detected source's
           // ID is embedded in the message's header
-          ignition::msgs::Double msg;
+          msgs::Double msg;
           auto header = msg.mutable_header();
           auto timeStamp = header->mutable_stamp();
           timeStamp->set_sec(simSeconds.count());
@@ -284,7 +284,7 @@ void LogicalAudioSensorPluginPrivate::CreateAudioSource(
   }
   _ids.insert(id);
 
-  ignition::math::Pose3d pose;
+  math::Pose3d pose;
   if (!_elem->HasElement("pose"))
   {
     ignwarn << "Audio source is missing a pose. "
@@ -293,7 +293,7 @@ void LogicalAudioSensorPluginPrivate::CreateAudioSource(
   }
   else
   {
-    pose = _elem->Get<ignition::math::Pose3d>("pose");
+    pose = _elem->Get<math::Pose3d>("pose");
   }
 
   if (!_elem->HasElement("attenuation_function"))
@@ -385,16 +385,16 @@ void LogicalAudioSensorPluginPrivate::CreateAudioSource(
       components::LogicalAudioSourcePlayInfo(playInfo));
 
   // create service callbacks that allow this source to be played/stopped
-  std::function<bool(ignition::msgs::Boolean &)> playSrvCb =
-    [this, entity](ignition::msgs::Boolean &_resp)
+  std::function<bool(msgs::Boolean &)> playSrvCb =
+    [this, entity](msgs::Boolean &_resp)
     {
       std::lock_guard<std::mutex> lock(this->playSourceMutex);
       this->sourceEntities[entity].first = true;
       _resp.set_data(true);
       return true;
     };
-  std::function<bool(ignition::msgs::Boolean &)> stopSrvCb =
-    [this, entity](ignition::msgs::Boolean &_resp)
+  std::function<bool(msgs::Boolean &)> stopSrvCb =
+    [this, entity](msgs::Boolean &_resp)
     {
       std::lock_guard<std::mutex> lock(this->stopSourceMutex);
       this->sourceEntities[entity].second = true;
@@ -447,7 +447,7 @@ void LogicalAudioSensorPluginPrivate::CreateMicrophone(
   }
   _ids.insert(id);
 
-  ignition::math::Pose3d pose;
+  math::Pose3d pose;
   if (!_elem->HasElement("pose"))
   {
     ignwarn << "Microphone is missing a pose. "
@@ -456,7 +456,7 @@ void LogicalAudioSensorPluginPrivate::CreateMicrophone(
   }
   else
   {
-    pose = _elem->Get<ignition::math::Pose3d>("pose");
+    pose = _elem->Get<math::Pose3d>("pose");
   }
 
   double volumeDetectionThreshold;
@@ -494,7 +494,7 @@ void LogicalAudioSensorPluginPrivate::CreateMicrophone(
       components::Pose(pose));
 
   // create the detection publisher for this microphone
-  auto pub = this->node.Advertise<ignition::msgs::Double>(
+  auto pub = this->node.Advertise<msgs::Double>(
       scopedName(entity, _ecm) + "/detection");
   if (!pub)
   {
@@ -519,7 +519,7 @@ bool LogicalAudioSensorPluginPrivate::DurationExceeded(
 }
 
 IGNITION_ADD_PLUGIN(LogicalAudioSensorPlugin,
-                    ignition::gazebo::System,
+                    System,
                     LogicalAudioSensorPlugin::ISystemConfigure,
                     LogicalAudioSensorPlugin::ISystemPreUpdate,
                     LogicalAudioSensorPlugin::ISystemPostUpdate)
