@@ -22,6 +22,7 @@
 #include <map>
 #include <string>
 #include <unordered_map>
+#include <unordered_set>
 #include <utility>
 
 #include <ignition/common/Profiler.hh>
@@ -59,23 +60,28 @@ class ignition::gazebo::systems::LogicalCameraPrivate
   /// \brief Ign-sensors sensor factory for creating sensors
   public: sensors::SensorFactory sensorFactory;
 
+  /// \brief Keep list of sensors that were created during the previous
+  /// `PostUpdate`, so that components can be created during the next
+  /// `PreUpdate`.
+  public: std::unordered_set<Entity> newSensors;
+
   /// True if the rendering component is initialized
   public: bool initialized = false;
 
   /// \brief Create sensor
-  /// \param[in] _ecm Mutable reference to ECM.
+  /// \param[in] _ecm Immutable reference to ECM.
   /// \param[in] _entity Entity of the IMU
   /// \param[in] _logicalCamera LogicalCamera component.
   /// \param[in] _parent Parent entity component.
   public: void AddLogicalCamera(
-    EntityComponentManager &_ecm,
+    const EntityComponentManager &_ecm,
     const Entity _entity,
     const components::LogicalCamera *_logicalCamera,
     const components::ParentEntity *_parent);
 
   /// \brief Create logicalCamera sensor
-  /// \param[in] _ecm Mutable reference to ECM.
-  public: void CreateLogicalCameraEntities(EntityComponentManager &_ecm);
+  /// \param[in] _ecm Immutable reference to ECM.
+  public: void CreateSensors(const EntityComponentManager &_ecm);
 
   /// \brief Update logicalCamera sensor data based on physics data
   /// \param[in] _ecm Immutable reference to ECM.
@@ -101,7 +107,21 @@ void LogicalCamera::PreUpdate(const UpdateInfo &/*_info*/,
     EntityComponentManager &_ecm)
 {
   IGN_PROFILE("LogicalCamera::PreUpdate");
-  this->dataPtr->CreateLogicalCameraEntities(_ecm);
+
+  // Create components
+  for (auto entity : this->dataPtr->newSensors)
+  {
+    auto it = this->dataPtr->entitySensorMap.find(entity);
+    if (it == this->dataPtr->entitySensorMap.end())
+    {
+      ignerr << "Entity [" << entity
+             << "] isn't in sensor map, this shouldn't happen." << std::endl;
+      continue;
+    }
+    // Set topic
+    _ecm.CreateComponent(entity, components::SensorTopic(it->second->Topic()));
+  }
+  this->dataPtr->newSensors.clear();
 }
 
 //////////////////////////////////////////////////
@@ -118,6 +138,8 @@ void LogicalCamera::PostUpdate(const UpdateInfo &_info,
         << "s]. System may not work properly." << std::endl;
   }
 
+  this->dataPtr->CreateSensors(_ecm);
+
   // Only update and publish if not paused.
   if (!_info.paused)
   {
@@ -137,7 +159,7 @@ void LogicalCamera::PostUpdate(const UpdateInfo &_info,
 
 //////////////////////////////////////////////////
 void LogicalCameraPrivate::AddLogicalCamera(
-  EntityComponentManager &_ecm,
+  const EntityComponentManager &_ecm,
   const Entity _entity,
   const components::LogicalCamera *_logicalCamera,
   const components::ParentEntity *_parent)
@@ -172,16 +194,13 @@ void LogicalCameraPrivate::AddLogicalCamera(
   math::Pose3d sensorWorldPose = worldPose(_entity, _ecm);
   sensor->SetPose(sensorWorldPose);
 
-  // Set topic
-  _ecm.CreateComponent(_entity, components::SensorTopic(sensor->Topic()));
-
   this->entitySensorMap.insert(
       std::make_pair(_entity, std::move(sensor)));
+  this->newSensors.insert(_entity);
 }
 
 //////////////////////////////////////////////////
-void LogicalCameraPrivate::CreateLogicalCameraEntities(
-    EntityComponentManager &_ecm)
+void LogicalCameraPrivate::CreateSensors(const EntityComponentManager &_ecm)
 {
   IGN_PROFILE("LogicalCameraPrivate::CreateLogicalCameraEntities");
   if (!this->initialized)
@@ -192,7 +211,7 @@ void LogicalCameraPrivate::CreateLogicalCameraEntities(
           const components::LogicalCamera *_logicalCamera,
           const components::ParentEntity *_parent)->bool
         {
-          AddLogicalCamera(_ecm, _entity, _logicalCamera, _parent);
+          this->AddLogicalCamera(_ecm, _entity, _logicalCamera, _parent);
           return true;
         });
     this->initialized = true;
@@ -206,7 +225,7 @@ void LogicalCameraPrivate::CreateLogicalCameraEntities(
           const components::LogicalCamera *_logicalCamera,
           const components::ParentEntity *_parent)->bool
         {
-          AddLogicalCamera(_ecm, _entity, _logicalCamera, _parent);
+          this->AddLogicalCamera(_ecm, _entity, _logicalCamera, _parent);
           return true;
         });
   }
