@@ -154,12 +154,12 @@ class ignition::gazebo::systems::PosePublisherPrivate
   /// \brief A variable that gets populated with poses. This also here as a
   /// member variable to avoid repeated memory allocations and improve
   /// performance.
-  public: ignition::msgs::Pose poseMsg;
+  public: msgs::Pose poseMsg;
 
   /// \brief A variable that gets populated with poses. This also here as a
   /// member variable to avoid repeated memory allocations and improve
   /// performance.
-  public: ignition::msgs::Pose_V poseVMsg;
+  public: msgs::Pose_V poseVMsg;
 
   /// \brief True to publish a vector of poses. False to publish individual pose
   /// msgs.
@@ -248,23 +248,23 @@ void PosePublisher::Configure(const Entity &_entity,
   if (this->dataPtr->usePoseV)
   {
     this->dataPtr->posePub =
-      this->dataPtr->node.Advertise<ignition::msgs::Pose_V>(poseTopic);
+      this->dataPtr->node.Advertise<msgs::Pose_V>(poseTopic);
 
     if (this->dataPtr->staticPosePublisher)
     {
       this->dataPtr->poseStaticPub =
-          this->dataPtr->node.Advertise<ignition::msgs::Pose_V>(
+          this->dataPtr->node.Advertise<msgs::Pose_V>(
           staticPoseTopic);
     }
   }
   else
   {
     this->dataPtr->posePub =
-      this->dataPtr->node.Advertise<ignition::msgs::Pose>(poseTopic);
+      this->dataPtr->node.Advertise<msgs::Pose>(poseTopic);
     if (this->dataPtr->staticPosePublisher)
     {
       this->dataPtr->poseStaticPub =
-          this->dataPtr->node.Advertise<ignition::msgs::Pose>(
+          this->dataPtr->node.Advertise<msgs::Pose>(
           staticPoseTopic);
     }
   }
@@ -498,7 +498,7 @@ void PosePublisherPrivate::PublishPoses(
   IGN_PROFILE("PosePublisher::PublishPoses");
 
   // publish poses
-  ignition::msgs::Pose *msg = nullptr;
+  msgs::Pose *msg = nullptr;
   if (this->usePoseV)
     this->poseVMsg.Clear();
 
