@@ -109,7 +109,7 @@ TEST_F(ComponentsTest, Actor)
   comp3.Deserialize(istr);
   EXPECT_EQ("abc", comp3.Data().Name());
   EXPECT_EQ("def", comp3.Data().SkinFilename());
-  EXPECT_EQ(ignition::math::Pose3d(3, 2, 1, 0, 0, 0), comp3.Data().RawPose());
+  EXPECT_EQ(math::Pose3d(3, 2, 1, 0, 0, 0), comp3.Data().RawPose());
 }
 
 /////////////////////////////////////////////////
@@ -118,7 +118,7 @@ TEST_F(ComponentsTest, AirPressureSensor)
   sdf::Sensor data1;
   data1.SetName("abc");
   data1.SetType(sdf::SensorType::AIR_PRESSURE);
-  data1.SetRawPose(ignition::math::Pose3d(1, 2, 3, 0, 0, 0));
+  data1.SetRawPose(math::Pose3d(1, 2, 3, 0, 0, 0));
 
   sdf::AirPressure airPressure1;
   data1.SetAirPressureSensor(airPressure1);
@@ -146,7 +146,7 @@ TEST_F(ComponentsTest, AirPressureSensor)
   comp3.Deserialize(istr);
   EXPECT_EQ("abc", comp3.Data().Name());
   EXPECT_EQ(sdf::SensorType::AIR_PRESSURE, comp3.Data().Type());
-  EXPECT_EQ(ignition::math::Pose3d(1, 2, 3, 0, 0, 0), comp3.Data().RawPose());
+  EXPECT_EQ(math::Pose3d(1, 2, 3, 0, 0, 0), comp3.Data().RawPose());
 }
 
 /////////////////////////////////////////////////
@@ -409,7 +409,7 @@ TEST_F(ComponentsTest, Imu)
   data1.SetType(sdf::SensorType::IMU);
   data1.SetUpdateRate(100);
   data1.SetTopic("imu_data");
-  data1.SetRawPose(ignition::math::Pose3d(1, 2, 3, 0, 0, 0));
+  data1.SetRawPose(math::Pose3d(1, 2, 3, 0, 0, 0));
 
   sdf::Imu imu1;
   data1.SetImuSensor(imu1);
@@ -440,7 +440,7 @@ TEST_F(ComponentsTest, Imu)
   EXPECT_EQ(sdf::SensorType::IMU, comp3.Data().Type());
   EXPECT_EQ("imu_data", comp3.Data().Topic());
   EXPECT_DOUBLE_EQ(100, comp3.Data().UpdateRate());
-  EXPECT_EQ(ignition::math::Pose3d(1, 2, 3, 0, 0, 0), comp3.Data().RawPose());
+  EXPECT_EQ(math::Pose3d(1, 2, 3, 0, 0, 0), comp3.Data().RawPose());
 }
 
 /////////////////////////////////////////////////
@@ -1033,7 +1033,7 @@ TEST_F(ComponentsTest, Magnetometer)
   data1.SetType(sdf::SensorType::MAGNETOMETER);
   data1.SetUpdateRate(12.4);
   data1.SetTopic("grape");
-  data1.SetRawPose(ignition::math::Pose3d(1, 2, 3, 0, 0, 0));
+  data1.SetRawPose(math::Pose3d(1, 2, 3, 0, 0, 0));
 
   sdf::Magnetometer mag1;
   data1.SetMagnetometerSensor(mag1);
@@ -1063,7 +1063,7 @@ TEST_F(ComponentsTest, Magnetometer)
   EXPECT_EQ(sdf::SensorType::MAGNETOMETER, comp3.Data().Type());
   EXPECT_EQ("grape", comp3.Data().Topic());
   EXPECT_DOUBLE_EQ(12.4, comp3.Data().UpdateRate());
-  EXPECT_EQ(ignition::math::Pose3d(1, 2, 3, 0, 0, 0), comp3.Data().RawPose());
+  EXPECT_EQ(math::Pose3d(1, 2, 3, 0, 0, 0), comp3.Data().RawPose());
 }
 
 /////////////////////////////////////////////////
