@@ -28,6 +28,7 @@
 #include <ignition/math/Pose3.hh>
 #include <ignition/msgs.hh>
 #include <ignition/transport.hh>
+#include <ignition/utilities/ExtraTestMacros.hh>
 
 #include "ignition/gazebo/components/LogicalAudio.hh"
 #include "ignition/gazebo/components/Pose.hh"
@@ -62,10 +63,10 @@ TEST_F(LogicalAudioTest, LogicalAudioDetections)
   EXPECT_FALSE(*server.Running(0));
 
   // helper variables for checking the validity of the ECM
-  const ignition::math::Pose3d sourcePose(0, 0, 0, 0, 0, 0);
+  const math::Pose3d sourcePose(0, 0, 0, 0, 0, 0);
   const auto zeroSeconds = std::chrono::seconds(0);
-  const ignition::math::Pose3d micClosePose(0.5, 0, 0, 0, 0, 0);
-  const ignition::math::Pose3d micFarPose(0, 0, 0, 0, 0, 0);
+  const math::Pose3d micClosePose(0.5, 0, 0, 0, 0, 0);
+  const math::Pose3d micFarPose(0, 0, 0, 0, 0, 0);
   std::chrono::steady_clock::duration sourceStartTime;
   bool firstTime{true};
 
@@ -204,7 +205,8 @@ TEST_F(LogicalAudioTest, LogicalAudioDetections)
       "world/logical_audio_sensor/model/source_model/sensor/source_1");
 }
 
-TEST_F(LogicalAudioTest, LogicalAudioServices)
+// See: https://github.com/gazebosim/gz-sim/issues/630
+TEST_F(LogicalAudioTest, IGN_UTILS_TEST_DISABLED_ON_MAC(LogicalAudioServices))
 {
   ServerConfig serverConfig;
   const auto sdfFile = std::string(PROJECT_SOURCE_PATH) +
