@@ -22,6 +22,7 @@
 #include <ignition/common/Util.hh>
 #include <ignition/math/Pose3.hh>
 #include <ignition/transport/Node.hh>
+#include <ignition/utilities/ExtraTestMacros.hh>
 
 #include "ignition/gazebo/components/Name.hh"
 #include "ignition/gazebo/components/Model.hh"
@@ -141,8 +142,8 @@ TEST_F(PosePublisherTest, PublishCmd)
       [&modelName, &baseName, &lowerLinkName, &upperLinkName, &sensorName,
       &poses, &basePoses, &lowerLinkPoses, &upperLinkPoses, &sensorPoses,
       &timestamps](
-      const gazebo::UpdateInfo &_info,
-      const gazebo::EntityComponentManager &_ecm)
+      const UpdateInfo &_info,
+      const EntityComponentManager &_ecm)
     {
       // get our double pendulum model
       auto id = _ecm.EntityByComponents(
@@ -189,7 +190,7 @@ TEST_F(PosePublisherTest, PublishCmd)
 
       // timestamps
       auto simTimeSecNsec =
-          ignition::math::durationToSecNsec(_info.simTime);
+          math::durationToSecNsec(_info.simTime);
        timestamps.push_back(
            common::Time(simTimeSecNsec.first, simTimeSecNsec.second));
     });
@@ -236,7 +237,7 @@ TEST_F(PosePublisherTest, PublishCmd)
 
   // sort the pose msgs according to timestamp
   std::sort(poseMsgs.begin(), poseMsgs.end(), [](
-      const ignition::msgs::Pose &_l, const ignition::msgs::Pose &_r)
+      const msgs::Pose &_l, const msgs::Pose &_r)
   {
     common::Time lt(_l.header().stamp().sec(), _l.header().stamp().nsec());
     common::Time rt(_r.header().stamp().sec(), _r.header().stamp().nsec());
@@ -309,7 +310,8 @@ TEST_F(PosePublisherTest, PublishCmd)
 }
 
 /////////////////////////////////////////////////
-TEST_F(PosePublisherTest, UpdateFrequency)
+// See: https://github.com/gazebosim/gz-sim/issues/630
+TEST_F(PosePublisherTest, IGN_UTILS_TEST_DISABLED_ON_MAC(UpdateFrequency))
 {
   // Start server
   ServerConfig serverConfig;
@@ -339,9 +341,9 @@ TEST_F(PosePublisherTest, UpdateFrequency)
   std::size_t nExpMessages = 100;
   // Wait for 100 messages to be received
   bool received = false;
-  for (int sleep = 0; sleep < 300; ++sleep)
+  for (int sleep = 0; sleep < 30; ++sleep)
   {
-    std::this_thread::sleep_for(std::chrono::milliseconds(10));
+    std::this_thread::sleep_for(std::chrono::milliseconds(100));
 
     {
       std::lock_guard<std::mutex> lock(mutex);
@@ -425,8 +427,8 @@ TEST_F(PosePublisherTest, StaticPosePublisher)
       [&modelName, &baseName, &lowerLinkName, &upperLinkName, &sensorName,
       &poses, &basePoses, &lowerLinkPoses, &upperLinkPoses, &sensorPoses,
       &timestamps, &staticPoseTimestamps](
-      const gazebo::UpdateInfo &_info,
-      const gazebo::EntityComponentManager &_ecm)
+      const UpdateInfo &_info,
+      const EntityComponentManager &_ecm)
     {
       // get our double pendulum model
       auto id = _ecm.EntityByComponents(
@@ -473,7 +475,7 @@ TEST_F(PosePublisherTest, StaticPosePublisher)
 
       // timestamps
       auto simTimeSecNsec =
-          ignition::math::durationToSecNsec(_info.simTime);
+          math::durationToSecNsec(_info.simTime);
       timestamps.push_back(
           common::Time(simTimeSecNsec.first, simTimeSecNsec.second));
       staticPoseTimestamps.push_back(
@@ -626,7 +628,9 @@ TEST_F(PosePublisherTest, StaticPosePublisher)
 }
 
 /////////////////////////////////////////////////
-TEST_F(PosePublisherTest, StaticPoseUpdateFrequency)
+// See: https://github.com/gazebosim/gz-sim/issues/630
+TEST_F(PosePublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_MAC(StaticPoseUpdateFrequency))
 {
   // Start server
   ServerConfig serverConfig;
@@ -657,9 +661,9 @@ TEST_F(PosePublisherTest, StaticPoseUpdateFrequency)
   std::size_t nExpMessages = 100;
   // Wait for 100 messages to be received
   bool received = false;
-  for (int sleep = 0; sleep < 300; ++sleep)
+  for (int sleep = 0; sleep < 30; ++sleep)
   {
-    std::this_thread::sleep_for(std::chrono::milliseconds(10));
+    std::this_thread::sleep_for(std::chrono::milliseconds(100));
 
     {
       std::lock_guard<std::mutex> lock(mutex);
@@ -717,9 +721,9 @@ TEST_F(PosePublisherTest, NestedModelLoadPlugin)
 
   // Wait for messages to be received
   int sleep = 0;
-  while (poseMsgs.empty() && sleep++ < 300)
+  while (poseMsgs.empty() && sleep++ < 30)
   {
-    std::this_thread::sleep_for(std::chrono::milliseconds(10));
+    std::this_thread::sleep_for(std::chrono::milliseconds(100));
   }
 
   EXPECT_TRUE(!poseMsgs.empty());
